# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SCENE_CAPTURE_IMAGE_METADATA = Metadata(
    id="55af0e180213a5b9c01ff3c05ec7ffefe348871b.boutiques",
    name="scene-capture-image",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SceneCaptureImageSizeWidthHeightParameters = typing.TypedDict('SceneCaptureImageSizeWidthHeightParameters', {
    "@type": typing.NotRequired[typing.Literal["size_width_height"]],
    "width": float,
    "height": float,
})
SceneCaptureImageSizeWidthHeightParametersTagged = typing.TypedDict('SceneCaptureImageSizeWidthHeightParametersTagged', {
    "@type": typing.Literal["size_width_height"],
    "width": float,
    "height": float,
})


SceneCaptureImageResolutionParameters = typing.TypedDict('SceneCaptureImageResolutionParameters', {
    "@type": typing.NotRequired[typing.Literal["resolution"]],
    "number_of_pixels": float,
    "units_name": str,
})
SceneCaptureImageResolutionParametersTagged = typing.TypedDict('SceneCaptureImageResolutionParametersTagged', {
    "@type": typing.Literal["resolution"],
    "number_of_pixels": float,
    "units_name": str,
})


SceneCaptureImageSetMapYokeParameters = typing.TypedDict('SceneCaptureImageSetMapYokeParameters', {
    "@type": typing.NotRequired[typing.Literal["set_map_yoke"]],
    "map_yoking_roman_numeral": str,
    "map_undex": int,
})
SceneCaptureImageSetMapYokeParametersTagged = typing.TypedDict('SceneCaptureImageSetMapYokeParametersTagged', {
    "@type": typing.Literal["set_map_yoke"],
    "map_yoking_roman_numeral": str,
    "map_undex": int,
})


SceneCaptureImageConnDbLoginParameters = typing.TypedDict('SceneCaptureImageConnDbLoginParameters', {
    "@type": typing.NotRequired[typing.Literal["conn_db_login"]],
    "username": str,
    "password": str,
})
SceneCaptureImageConnDbLoginParametersTagged = typing.TypedDict('SceneCaptureImageConnDbLoginParametersTagged', {
    "@type": typing.Literal["conn_db_login"],
    "username": str,
    "password": str,
})


SceneCaptureImageParameters = typing.TypedDict('SceneCaptureImageParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/scene-capture-image"]],
    "scene_file": str,
    "scene_name_or_number": str,
    "image_file_name": str,
    "opt_size_window": bool,
    "opt_size_capture": bool,
    "size_width_height": typing.NotRequired[SceneCaptureImageSizeWidthHeightParameters | None],
    "opt_size_width_width": typing.NotRequired[float | None],
    "opt_size_height_height": typing.NotRequired[float | None],
    "opt_units_units": typing.NotRequired[str | None],
    "resolution": typing.NotRequired[SceneCaptureImageResolutionParameters | None],
    "opt_margin_size": typing.NotRequired[int | None],
    "opt_no_scene_colors": bool,
    "set_map_yoke": typing.NotRequired[SceneCaptureImageSetMapYokeParameters | None],
    "conn_db_login": typing.NotRequired[SceneCaptureImageConnDbLoginParameters | None],
    "opt_show_capture_settings": bool,
    "opt_renderer_renderer": typing.NotRequired[str | None],
    "opt_print_image_info": bool,
})
SceneCaptureImageParametersTagged = typing.TypedDict('SceneCaptureImageParametersTagged', {
    "@type": typing.Literal["workbench/scene-capture-image"],
    "scene_file": str,
    "scene_name_or_number": str,
    "image_file_name": str,
    "opt_size_window": bool,
    "opt_size_capture": bool,
    "size_width_height": typing.NotRequired[SceneCaptureImageSizeWidthHeightParameters | None],
    "opt_size_width_width": typing.NotRequired[float | None],
    "opt_size_height_height": typing.NotRequired[float | None],
    "opt_units_units": typing.NotRequired[str | None],
    "resolution": typing.NotRequired[SceneCaptureImageResolutionParameters | None],
    "opt_margin_size": typing.NotRequired[int | None],
    "opt_no_scene_colors": bool,
    "set_map_yoke": typing.NotRequired[SceneCaptureImageSetMapYokeParameters | None],
    "conn_db_login": typing.NotRequired[SceneCaptureImageConnDbLoginParameters | None],
    "opt_show_capture_settings": bool,
    "opt_renderer_renderer": typing.NotRequired[str | None],
    "opt_print_image_info": bool,
})


def scene_capture_image_size_width_height_params(
    width: float,
    height: float,
) -> SceneCaptureImageSizeWidthHeightParametersTagged:
    """
    Build parameters.
    
    Args:
        width: Width for output image.
        height: Height for output image.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "size_width_height",
        "width": width,
        "height": height,
    }
    return params


def scene_capture_image_size_width_height_cargs(
    params: SceneCaptureImageSizeWidthHeightParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-size-width-height")
    cargs.append(str(params.get("width", None)))
    cargs.append(str(params.get("height", None)))
    return cargs


def scene_capture_image_resolution_params(
    number_of_pixels: float,
    units_name: str,
) -> SceneCaptureImageResolutionParametersTagged:
    """
    Build parameters.
    
    Args:
        number_of_pixels: number of pixels.
        units_name: Name of resolution units. Valid resolution unit names are:\
            PIXELS_PER_INCH\
            PIXELS_PER_CENTIMETER\
            PIXELS_PER_METER\
            PIXELS_PER_MILLIMETER.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "resolution",
        "number_of_pixels": number_of_pixels,
        "units_name": units_name,
    }
    return params


def scene_capture_image_resolution_cargs(
    params: SceneCaptureImageResolutionParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-resolution")
    cargs.append(str(params.get("number_of_pixels", None)))
    cargs.append(params.get("units_name", None))
    return cargs


def scene_capture_image_set_map_yoke_params(
    map_yoking_roman_numeral: str,
    map_undex: int,
) -> SceneCaptureImageSetMapYokeParametersTagged:
    """
    Build parameters.
    
    Args:
        map_yoking_roman_numeral: Roman numeral identifying the map yoking\
            group (I, II, III, IV, V, VI, VII, VIII, IX, X).
        map_undex: Map index for yoking group. Indices start at 1 (one).
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "set_map_yoke",
        "map_yoking_roman_numeral": map_yoking_roman_numeral,
        "map_undex": map_undex,
    }
    return params


def scene_capture_image_set_map_yoke_cargs(
    params: SceneCaptureImageSetMapYokeParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-set-map-yoke")
    cargs.append(params.get("map_yoking_roman_numeral", None))
    cargs.append(str(params.get("map_undex", None)))
    return cargs


def scene_capture_image_conn_db_login_params(
    username: str,
    password: str,
) -> SceneCaptureImageConnDbLoginParametersTagged:
    """
    Build parameters.
    
    Args:
        username: Connectome DB Username.
        password: Connectome DB Password.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "conn_db_login",
        "username": username,
        "password": password,
    }
    return params


def scene_capture_image_conn_db_login_cargs(
    params: SceneCaptureImageConnDbLoginParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-conn-db-login")
    cargs.append(params.get("username", None))
    cargs.append(params.get("password", None))
    return cargs


class SceneCaptureImageOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SceneCaptureImageParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def scene_capture_image_params(
    scene_file: str,
    scene_name_or_number: str,
    image_file_name: str,
    opt_size_window: bool = False,
    opt_size_capture: bool = False,
    size_width_height: SceneCaptureImageSizeWidthHeightParameters | None = None,
    opt_size_width_width: float | None = None,
    opt_size_height_height: float | None = None,
    opt_units_units: str | None = None,
    resolution: SceneCaptureImageResolutionParameters | None = None,
    opt_margin_size: int | None = None,
    opt_no_scene_colors: bool = False,
    set_map_yoke: SceneCaptureImageSetMapYokeParameters | None = None,
    conn_db_login: SceneCaptureImageConnDbLoginParameters | None = None,
    opt_show_capture_settings: bool = False,
    opt_renderer_renderer: str | None = None,
    opt_print_image_info: bool = False,
) -> SceneCaptureImageParametersTagged:
    """
    Build parameters.
    
    Args:
        scene_file: scene file.
        scene_name_or_number: name or number (starting at one) of the scene in\
            the scene file.
        image_file_name: output - image file name\
            The file name must end with a valid extension that identifies the\
            image file format. Valid extensions on this system are: (.bmp .jpeg\
            .jpg .png .ppm).\
            \
            If there is more than one window in the scene, multiple image files\
            are output with the window's number inserted into the name of the\
            image file immediately before the image file's extension.
        opt_size_window: Output image is size of window's graphics region from\
            when scene was created.
        opt_size_capture: Output image uses size from Capture Dialog when scene\
            was created.
        size_width_height: Width and height for output image.
        opt_size_width_width: Width for output image. Height is computed using\
            the aspect ratio from the window's width and height saved in the\
            scene.: Width for output image.
        opt_size_height_height: Height for output image. Width is computed\
            using the aspect ratio from the window's width and height saved in the\
            scene.: Height for output image.
        opt_units_units: Units for image width/height\
            Default is PIXELS: Name of units for image width/height. Valid\
            units are:\
            INCHES\
            CENTIMETERS\
            MILLIMETERS\
            METERS\
            PIXELS.
        resolution: Image resolution (number pixels per size unit)\
            Default is 300 PIXELS_PER_INCH.
        opt_margin_size: Add a margin to sides of the image using the window's\
            background color.: size of margin, in pixels, added to all sides of\
            output image.
        opt_no_scene_colors: Do not use background and foreground colors in\
            scene.
        set_map_yoke: Override selected map index for a map yoking group.
        conn_db_login: Login for scenes with files in Connectome Database. If\
            this option is not specified, the login and password stored in the\
            user's preferences is used.
        opt_show_capture_settings: Print settings from Capture Dialog only, DO\
            NOT create image file(s).
        opt_renderer_renderer: Select renderer for drawing image: Name of\
            renderer to use for drawing image.
        opt_print_image_info: Print the size and other information about output\
            images only and DO NOT create any output images.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/scene-capture-image",
        "scene_file": scene_file,
        "scene_name_or_number": scene_name_or_number,
        "image_file_name": image_file_name,
        "opt_size_window": opt_size_window,
        "opt_size_capture": opt_size_capture,
        "opt_no_scene_colors": opt_no_scene_colors,
        "opt_show_capture_settings": opt_show_capture_settings,
        "opt_print_image_info": opt_print_image_info,
    }
    if size_width_height is not None:
        params["size_width_height"] = size_width_height
    if opt_size_width_width is not None:
        params["opt_size_width_width"] = opt_size_width_width
    if opt_size_height_height is not None:
        params["opt_size_height_height"] = opt_size_height_height
    if opt_units_units is not None:
        params["opt_units_units"] = opt_units_units
    if resolution is not None:
        params["resolution"] = resolution
    if opt_margin_size is not None:
        params["opt_margin_size"] = opt_margin_size
    if set_map_yoke is not None:
        params["set_map_yoke"] = set_map_yoke
    if conn_db_login is not None:
        params["conn_db_login"] = conn_db_login
    if opt_renderer_renderer is not None:
        params["opt_renderer_renderer"] = opt_renderer_renderer
    return params


def scene_capture_image_cargs(
    params: SceneCaptureImageParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-scene-capture-image")
    cargs.append(params.get("scene_file", None))
    cargs.append(params.get("scene_name_or_number", None))
    cargs.append(params.get("image_file_name", None))
    if params.get("opt_size_window", False):
        cargs.append("-size-window")
    if params.get("opt_size_capture", False):
        cargs.append("-size-capture")
    if params.get("size_width_height", None) is not None:
        cargs.extend(scene_capture_image_size_width_height_cargs(params.get("size_width_height", None), execution))
    if params.get("opt_size_width_width", None) is not None:
        cargs.extend([
            "-size-width",
            str(params.get("opt_size_width_width", None))
        ])
    if params.get("opt_size_height_height", None) is not None:
        cargs.extend([
            "-size-height",
            str(params.get("opt_size_height_height", None))
        ])
    if params.get("opt_units_units", None) is not None:
        cargs.extend([
            "-units",
            params.get("opt_units_units", None)
        ])
    if params.get("resolution", None) is not None:
        cargs.extend(scene_capture_image_resolution_cargs(params.get("resolution", None), execution))
    if params.get("opt_margin_size", None) is not None:
        cargs.extend([
            "-margin",
            str(params.get("opt_margin_size", None))
        ])
    if params.get("opt_no_scene_colors", False):
        cargs.append("-no-scene-colors")
    if params.get("set_map_yoke", None) is not None:
        cargs.extend(scene_capture_image_set_map_yoke_cargs(params.get("set_map_yoke", None), execution))
    if params.get("conn_db_login", None) is not None:
        cargs.extend(scene_capture_image_conn_db_login_cargs(params.get("conn_db_login", None), execution))
    if params.get("opt_show_capture_settings", False):
        cargs.append("-show-capture-settings")
    if params.get("opt_renderer_renderer", None) is not None:
        cargs.extend([
            "-renderer",
            params.get("opt_renderer_renderer", None)
        ])
    if params.get("opt_print_image_info", False):
        cargs.append("-print-image-info")
    return cargs


def scene_capture_image_outputs(
    params: SceneCaptureImageParameters,
    execution: Execution,
) -> SceneCaptureImageOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SceneCaptureImageOutputs(
        root=execution.output_file("."),
    )
    return ret


def scene_capture_image_execute(
    params: SceneCaptureImageParameters,
    runner: Runner | None = None,
) -> SceneCaptureImageOutputs:
    """
    scene-capture-image
    
    Offscreen rendering of scene to an image file.
    
    ----------------------------------------------------------------------
    
    Render content of browser windows displayed in a scene into image file(s).
    
    If none of the "-size" options are specified, the default is "-size-window"
    (Output image is size of the window that was saved in the scene).
    
    For the "-size" options that accept a width and/or height, the values
    default to number of pixels. To express the width and/or height in physical
    units (inches, centimeters, etc.), use the "-units" option. When physical
    units are used, the pixel width and height are derived using the physical
    width/height and the image resolution (see the "-resolution" option).
    
    Note that scenes created prior to version 1.2 (May 2016) do not contain
    information about the size of the window. Therefore, one must use the
    "-size-width-height" option.
    
    Examples:
    
    Generate an image of the second scene. Width and height of image is width
    and height of window saved in the scene.
    wb_command -scene-capture-image myscene.scene 2 image2.jpg
    
    Generate an image of the second scene with a margin around sides of the
    image. Width and height of image is width and height of window saved in the
    scene.
    wb_command -scene-capture-image myscene.scene 2 image2.jpg -margin 10
    
    Generate an image of the second scene that is 6 inches width with 300 pixels
    per inch. The resulting width is 1800 pixels. The resulting height of the
    image is a function of the width and the aspect ratio (height divided by
    width) of the window size saved in the scene.
    wb_command -scene-capture-image myscene.scene 2 image21.jpg \\
    -size-width 6 -units INCHES -resolution 300 PIXELS_PER_INCH
    
    Print information about the size of the output image for the second scene
    (no image file is created) using a width of 4.5 centimeters.
    wb_command -scene-capture-image myscene.scene 2 test.jpg \\
    -size-width 4.5 -units CENTIMETERS -print-image-info
    
    
    
    
    NO OFF SCREEN RENDERERS AVAILABLE ON THIS SYSTEM. COMMAND WILL FAIL !!!!
    
    
    ERROR: -scene-capture-image is not available !
    A required library for this command, Mesa3D (software version of OpenGL),
    was not available when this software was created. This command is not
    available for the Windows version of this software but should always be
    available in the Linux and MacOS versions.
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SceneCaptureImageOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SCENE_CAPTURE_IMAGE_METADATA)
    params = execution.params(params)
    cargs = scene_capture_image_cargs(params, execution)
    ret = scene_capture_image_outputs(params, execution)
    execution.run(cargs)
    return ret


def scene_capture_image(
    scene_file: str,
    scene_name_or_number: str,
    image_file_name: str,
    opt_size_window: bool = False,
    opt_size_capture: bool = False,
    size_width_height: SceneCaptureImageSizeWidthHeightParameters | None = None,
    opt_size_width_width: float | None = None,
    opt_size_height_height: float | None = None,
    opt_units_units: str | None = None,
    resolution: SceneCaptureImageResolutionParameters | None = None,
    opt_margin_size: int | None = None,
    opt_no_scene_colors: bool = False,
    set_map_yoke: SceneCaptureImageSetMapYokeParameters | None = None,
    conn_db_login: SceneCaptureImageConnDbLoginParameters | None = None,
    opt_show_capture_settings: bool = False,
    opt_renderer_renderer: str | None = None,
    opt_print_image_info: bool = False,
    runner: Runner | None = None,
) -> SceneCaptureImageOutputs:
    """
    scene-capture-image
    
    Offscreen rendering of scene to an image file.
    
    ----------------------------------------------------------------------
    
    Render content of browser windows displayed in a scene into image file(s).
    
    If none of the "-size" options are specified, the default is "-size-window"
    (Output image is size of the window that was saved in the scene).
    
    For the "-size" options that accept a width and/or height, the values
    default to number of pixels. To express the width and/or height in physical
    units (inches, centimeters, etc.), use the "-units" option. When physical
    units are used, the pixel width and height are derived using the physical
    width/height and the image resolution (see the "-resolution" option).
    
    Note that scenes created prior to version 1.2 (May 2016) do not contain
    information about the size of the window. Therefore, one must use the
    "-size-width-height" option.
    
    Examples:
    
    Generate an image of the second scene. Width and height of image is width
    and height of window saved in the scene.
    wb_command -scene-capture-image myscene.scene 2 image2.jpg
    
    Generate an image of the second scene with a margin around sides of the
    image. Width and height of image is width and height of window saved in the
    scene.
    wb_command -scene-capture-image myscene.scene 2 image2.jpg -margin 10
    
    Generate an image of the second scene that is 6 inches width with 300 pixels
    per inch. The resulting width is 1800 pixels. The resulting height of the
    image is a function of the width and the aspect ratio (height divided by
    width) of the window size saved in the scene.
    wb_command -scene-capture-image myscene.scene 2 image21.jpg \\
    -size-width 6 -units INCHES -resolution 300 PIXELS_PER_INCH
    
    Print information about the size of the output image for the second scene
    (no image file is created) using a width of 4.5 centimeters.
    wb_command -scene-capture-image myscene.scene 2 test.jpg \\
    -size-width 4.5 -units CENTIMETERS -print-image-info
    
    
    
    
    NO OFF SCREEN RENDERERS AVAILABLE ON THIS SYSTEM. COMMAND WILL FAIL !!!!
    
    
    ERROR: -scene-capture-image is not available !
    A required library for this command, Mesa3D (software version of OpenGL),
    was not available when this software was created. This command is not
    available for the Windows version of this software but should always be
    available in the Linux and MacOS versions.
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        scene_file: scene file.
        scene_name_or_number: name or number (starting at one) of the scene in\
            the scene file.
        image_file_name: output - image file name\
            The file name must end with a valid extension that identifies the\
            image file format. Valid extensions on this system are: (.bmp .jpeg\
            .jpg .png .ppm).\
            \
            If there is more than one window in the scene, multiple image files\
            are output with the window's number inserted into the name of the\
            image file immediately before the image file's extension.
        opt_size_window: Output image is size of window's graphics region from\
            when scene was created.
        opt_size_capture: Output image uses size from Capture Dialog when scene\
            was created.
        size_width_height: Width and height for output image.
        opt_size_width_width: Width for output image. Height is computed using\
            the aspect ratio from the window's width and height saved in the\
            scene.: Width for output image.
        opt_size_height_height: Height for output image. Width is computed\
            using the aspect ratio from the window's width and height saved in the\
            scene.: Height for output image.
        opt_units_units: Units for image width/height\
            Default is PIXELS: Name of units for image width/height. Valid\
            units are:\
            INCHES\
            CENTIMETERS\
            MILLIMETERS\
            METERS\
            PIXELS.
        resolution: Image resolution (number pixels per size unit)\
            Default is 300 PIXELS_PER_INCH.
        opt_margin_size: Add a margin to sides of the image using the window's\
            background color.: size of margin, in pixels, added to all sides of\
            output image.
        opt_no_scene_colors: Do not use background and foreground colors in\
            scene.
        set_map_yoke: Override selected map index for a map yoking group.
        conn_db_login: Login for scenes with files in Connectome Database. If\
            this option is not specified, the login and password stored in the\
            user's preferences is used.
        opt_show_capture_settings: Print settings from Capture Dialog only, DO\
            NOT create image file(s).
        opt_renderer_renderer: Select renderer for drawing image: Name of\
            renderer to use for drawing image.
        opt_print_image_info: Print the size and other information about output\
            images only and DO NOT create any output images.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SceneCaptureImageOutputs`).
    """
    params = scene_capture_image_params(
        scene_file=scene_file,
        scene_name_or_number=scene_name_or_number,
        image_file_name=image_file_name,
        opt_size_window=opt_size_window,
        opt_size_capture=opt_size_capture,
        size_width_height=size_width_height,
        opt_size_width_width=opt_size_width_width,
        opt_size_height_height=opt_size_height_height,
        opt_units_units=opt_units_units,
        resolution=resolution,
        opt_margin_size=opt_margin_size,
        opt_no_scene_colors=opt_no_scene_colors,
        set_map_yoke=set_map_yoke,
        conn_db_login=conn_db_login,
        opt_show_capture_settings=opt_show_capture_settings,
        opt_renderer_renderer=opt_renderer_renderer,
        opt_print_image_info=opt_print_image_info,
    )
    return scene_capture_image_execute(params, runner)


__all__ = [
    "SCENE_CAPTURE_IMAGE_METADATA",
    "SceneCaptureImageOutputs",
    "scene_capture_image",
    "scene_capture_image_conn_db_login_params",
    "scene_capture_image_execute",
    "scene_capture_image_params",
    "scene_capture_image_resolution_params",
    "scene_capture_image_set_map_yoke_params",
    "scene_capture_image_size_width_height_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_FALSE_CORRELATION_METADATA = Metadata(
    id="1eacf54b399e5ccb46fa2416a02ea0a697253276.boutiques",
    name="cifti-false-correlation",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiFalseCorrelationLeftSurfaceParameters = typing.TypedDict('CiftiFalseCorrelationLeftSurfaceParameters', {
    "@type": typing.NotRequired[typing.Literal["left_surface"]],
    "surface": InputPathType,
    "opt_dump_text_text_out": typing.NotRequired[str | None],
})
CiftiFalseCorrelationLeftSurfaceParametersTagged = typing.TypedDict('CiftiFalseCorrelationLeftSurfaceParametersTagged', {
    "@type": typing.Literal["left_surface"],
    "surface": InputPathType,
    "opt_dump_text_text_out": typing.NotRequired[str | None],
})


CiftiFalseCorrelationRightSurfaceParameters = typing.TypedDict('CiftiFalseCorrelationRightSurfaceParameters', {
    "@type": typing.NotRequired[typing.Literal["right_surface"]],
    "surface": InputPathType,
    "opt_dump_text_text_out": typing.NotRequired[str | None],
})
CiftiFalseCorrelationRightSurfaceParametersTagged = typing.TypedDict('CiftiFalseCorrelationRightSurfaceParametersTagged', {
    "@type": typing.Literal["right_surface"],
    "surface": InputPathType,
    "opt_dump_text_text_out": typing.NotRequired[str | None],
})


CiftiFalseCorrelationCerebellumSurfaceParameters = typing.TypedDict('CiftiFalseCorrelationCerebellumSurfaceParameters', {
    "@type": typing.NotRequired[typing.Literal["cerebellum_surface"]],
    "surface": InputPathType,
    "opt_dump_text_text_out": typing.NotRequired[str | None],
})
CiftiFalseCorrelationCerebellumSurfaceParametersTagged = typing.TypedDict('CiftiFalseCorrelationCerebellumSurfaceParametersTagged', {
    "@type": typing.Literal["cerebellum_surface"],
    "surface": InputPathType,
    "opt_dump_text_text_out": typing.NotRequired[str | None],
})


CiftiFalseCorrelationParameters = typing.TypedDict('CiftiFalseCorrelationParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-false-correlation"]],
    "cifti_in": InputPathType,
    "3d_dist": float,
    "geo_outer": float,
    "geo_inner": float,
    "cifti_out": str,
    "left_surface": typing.NotRequired[CiftiFalseCorrelationLeftSurfaceParameters | None],
    "right_surface": typing.NotRequired[CiftiFalseCorrelationRightSurfaceParameters | None],
    "cerebellum_surface": typing.NotRequired[CiftiFalseCorrelationCerebellumSurfaceParameters | None],
})
CiftiFalseCorrelationParametersTagged = typing.TypedDict('CiftiFalseCorrelationParametersTagged', {
    "@type": typing.Literal["workbench/cifti-false-correlation"],
    "cifti_in": InputPathType,
    "3d_dist": float,
    "geo_outer": float,
    "geo_inner": float,
    "cifti_out": str,
    "left_surface": typing.NotRequired[CiftiFalseCorrelationLeftSurfaceParameters | None],
    "right_surface": typing.NotRequired[CiftiFalseCorrelationRightSurfaceParameters | None],
    "cerebellum_surface": typing.NotRequired[CiftiFalseCorrelationCerebellumSurfaceParameters | None],
})


def cifti_false_correlation_left_surface_params(
    surface: InputPathType,
    opt_dump_text_text_out: str | None = None,
) -> CiftiFalseCorrelationLeftSurfaceParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the left surface file.
        opt_dump_text_text_out: dump the raw measures used to a text file: the\
            output text file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "left_surface",
        "surface": surface,
    }
    if opt_dump_text_text_out is not None:
        params["opt_dump_text_text_out"] = opt_dump_text_text_out
    return params


def cifti_false_correlation_left_surface_cargs(
    params: CiftiFalseCorrelationLeftSurfaceParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-left-surface")
    cargs.append(execution.input_file(params.get("surface", None)))
    if params.get("opt_dump_text_text_out", None) is not None:
        cargs.extend([
            "-dump-text",
            params.get("opt_dump_text_text_out", None)
        ])
    return cargs


def cifti_false_correlation_right_surface_params(
    surface: InputPathType,
    opt_dump_text_text_out: str | None = None,
) -> CiftiFalseCorrelationRightSurfaceParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the right surface file.
        opt_dump_text_text_out: dump the raw measures used to a text file: the\
            output text file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "right_surface",
        "surface": surface,
    }
    if opt_dump_text_text_out is not None:
        params["opt_dump_text_text_out"] = opt_dump_text_text_out
    return params


def cifti_false_correlation_right_surface_cargs(
    params: CiftiFalseCorrelationRightSurfaceParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-right-surface")
    cargs.append(execution.input_file(params.get("surface", None)))
    if params.get("opt_dump_text_text_out", None) is not None:
        cargs.extend([
            "-dump-text",
            params.get("opt_dump_text_text_out", None)
        ])
    return cargs


def cifti_false_correlation_cerebellum_surface_params(
    surface: InputPathType,
    opt_dump_text_text_out: str | None = None,
) -> CiftiFalseCorrelationCerebellumSurfaceParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the cerebellum surface file.
        opt_dump_text_text_out: dump the raw measures used to a text file: the\
            output text file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "cerebellum_surface",
        "surface": surface,
    }
    if opt_dump_text_text_out is not None:
        params["opt_dump_text_text_out"] = opt_dump_text_text_out
    return params


def cifti_false_correlation_cerebellum_surface_cargs(
    params: CiftiFalseCorrelationCerebellumSurfaceParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-cerebellum-surface")
    cargs.append(execution.input_file(params.get("surface", None)))
    if params.get("opt_dump_text_text_out", None) is not None:
        cargs.extend([
            "-dump-text",
            params.get("opt_dump_text_text_out", None)
        ])
    return cargs


class CiftiFalseCorrelationOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiFalseCorrelationParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti dscalar file"""


def cifti_false_correlation_params(
    cifti_in: InputPathType,
    v_3d_dist: float,
    geo_outer: float,
    geo_inner: float,
    cifti_out: str,
    left_surface: CiftiFalseCorrelationLeftSurfaceParameters | None = None,
    right_surface: CiftiFalseCorrelationRightSurfaceParameters | None = None,
    cerebellum_surface: CiftiFalseCorrelationCerebellumSurfaceParameters | None = None,
) -> CiftiFalseCorrelationParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_in: the cifti file to use for correlation.
        v_3d_dist: maximum 3D distance to check around each vertex.
        geo_outer: maximum geodesic distance to use for neighboring correlation.
        geo_inner: minimum geodesic distance to use for neighboring correlation.
        cifti_out: the output cifti dscalar file.
        left_surface: specify the left surface to use.
        right_surface: specify the right surface to use.
        cerebellum_surface: specify the cerebellum surface to use.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-false-correlation",
        "cifti_in": cifti_in,
        "3d_dist": v_3d_dist,
        "geo_outer": geo_outer,
        "geo_inner": geo_inner,
        "cifti_out": cifti_out,
    }
    if left_surface is not None:
        params["left_surface"] = left_surface
    if right_surface is not None:
        params["right_surface"] = right_surface
    if cerebellum_surface is not None:
        params["cerebellum_surface"] = cerebellum_surface
    return params


def cifti_false_correlation_cargs(
    params: CiftiFalseCorrelationParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-false-correlation")
    cargs.append(execution.input_file(params.get("cifti_in", None)))
    cargs.append(str(params.get("3d_dist", None)))
    cargs.append(str(params.get("geo_outer", None)))
    cargs.append(str(params.get("geo_inner", None)))
    cargs.append(params.get("cifti_out", None))
    if params.get("left_surface", None) is not None:
        cargs.extend(cifti_false_correlation_left_surface_cargs(params.get("left_surface", None), execution))
    if params.get("right_surface", None) is not None:
        cargs.extend(cifti_false_correlation_right_surface_cargs(params.get("right_surface", None), execution))
    if params.get("cerebellum_surface", None) is not None:
        cargs.extend(cifti_false_correlation_cerebellum_surface_cargs(params.get("cerebellum_surface", None), execution))
    return cargs


def cifti_false_correlation_outputs(
    params: CiftiFalseCorrelationParameters,
    execution: Execution,
) -> CiftiFalseCorrelationOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiFalseCorrelationOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


def cifti_false_correlation_execute(
    params: CiftiFalseCorrelationParameters,
    runner: Runner | None = None,
) -> CiftiFalseCorrelationOutputs:
    """
    cifti-false-correlation
    
    Compare correlation locally and across/through sulci/gyri.
    
    For each vertex, compute the average correlation within a range of geodesic
    distances that don't cross a sulcus/gyrus, and the correlation to the
    closest vertex crossing a sulcus/gyrus. A vertex is considered to cross a
    sulcus/gyrus if the 3D distance is less than a third of the geodesic
    distance. The output file contains the ratio between these correlations, and
    some additional maps to help explain the ratio.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiFalseCorrelationOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_FALSE_CORRELATION_METADATA)
    params = execution.params(params)
    cargs = cifti_false_correlation_cargs(params, execution)
    ret = cifti_false_correlation_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_false_correlation(
    cifti_in: InputPathType,
    v_3d_dist: float,
    geo_outer: float,
    geo_inner: float,
    cifti_out: str,
    left_surface: CiftiFalseCorrelationLeftSurfaceParameters | None = None,
    right_surface: CiftiFalseCorrelationRightSurfaceParameters | None = None,
    cerebellum_surface: CiftiFalseCorrelationCerebellumSurfaceParameters | None = None,
    runner: Runner | None = None,
) -> CiftiFalseCorrelationOutputs:
    """
    cifti-false-correlation
    
    Compare correlation locally and across/through sulci/gyri.
    
    For each vertex, compute the average correlation within a range of geodesic
    distances that don't cross a sulcus/gyrus, and the correlation to the
    closest vertex crossing a sulcus/gyrus. A vertex is considered to cross a
    sulcus/gyrus if the 3D distance is less than a third of the geodesic
    distance. The output file contains the ratio between these correlations, and
    some additional maps to help explain the ratio.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti_in: the cifti file to use for correlation.
        v_3d_dist: maximum 3D distance to check around each vertex.
        geo_outer: maximum geodesic distance to use for neighboring correlation.
        geo_inner: minimum geodesic distance to use for neighboring correlation.
        cifti_out: the output cifti dscalar file.
        left_surface: specify the left surface to use.
        right_surface: specify the right surface to use.
        cerebellum_surface: specify the cerebellum surface to use.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiFalseCorrelationOutputs`).
    """
    params = cifti_false_correlation_params(
        cifti_in=cifti_in,
        v_3d_dist=v_3d_dist,
        geo_outer=geo_outer,
        geo_inner=geo_inner,
        cifti_out=cifti_out,
        left_surface=left_surface,
        right_surface=right_surface,
        cerebellum_surface=cerebellum_surface,
    )
    return cifti_false_correlation_execute(params, runner)


__all__ = [
    "CIFTI_FALSE_CORRELATION_METADATA",
    "CiftiFalseCorrelationOutputs",
    "cifti_false_correlation",
    "cifti_false_correlation_cerebellum_surface_params",
    "cifti_false_correlation_execute",
    "cifti_false_correlation_left_surface_params",
    "cifti_false_correlation_params",
    "cifti_false_correlation_right_surface_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_CREATE_SPHERE_METADATA = Metadata(
    id="e9b682a64a3a4ad0a40ee2b17e295fcee37251d0.boutiques",
    name="surface-create-sphere",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceCreateSphereParameters = typing.TypedDict('SurfaceCreateSphereParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-create-sphere"]],
    "num_vertices": int,
    "sphere_out": str,
})
SurfaceCreateSphereParametersTagged = typing.TypedDict('SurfaceCreateSphereParametersTagged', {
    "@type": typing.Literal["workbench/surface-create-sphere"],
    "num_vertices": int,
    "sphere_out": str,
})


class SurfaceCreateSphereOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceCreateSphereParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    sphere_out: OutputPathType
    """the output sphere"""


def surface_create_sphere_params(
    num_vertices: int,
    sphere_out: str,
) -> SurfaceCreateSphereParametersTagged:
    """
    Build parameters.
    
    Args:
        num_vertices: desired number of vertices.
        sphere_out: the output sphere.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-create-sphere",
        "num_vertices": num_vertices,
        "sphere_out": sphere_out,
    }
    return params


def surface_create_sphere_cargs(
    params: SurfaceCreateSphereParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-create-sphere")
    cargs.append(str(params.get("num_vertices", None)))
    cargs.append(params.get("sphere_out", None))
    return cargs


def surface_create_sphere_outputs(
    params: SurfaceCreateSphereParameters,
    execution: Execution,
) -> SurfaceCreateSphereOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceCreateSphereOutputs(
        root=execution.output_file("."),
        sphere_out=execution.output_file(params.get("sphere_out", None)),
    )
    return ret


def surface_create_sphere_execute(
    params: SurfaceCreateSphereParameters,
    runner: Runner | None = None,
) -> SurfaceCreateSphereOutputs:
    """
    surface-create-sphere
    
    Generate a sphere with consistent vertex areas.
    
    Generates a sphere by regularly dividing the triangles of an icosahedron, to
    come as close to the desired number of vertices as possible, and modifying
    it to have very similar vertex areas for all vertices. To generate a pair of
    vertex-matched left and right spheres, use this command, then
    -surface-flip-lr to generate the other sphere, then -set-structure on each.
    For example:
    
    $ wb_command -surface-create-sphere 6000 Sphere.6k.R.surf.gii
    $ wb_command -surface-flip-lr Sphere.6k.R.surf.gii Sphere.6k.L.surf.gii
    $ wb_command -set-structure Sphere.6k.R.surf.gii CORTEX_RIGHT
    $ wb_command -set-structure Sphere.6k.L.surf.gii CORTEX_LEFT.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceCreateSphereOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_CREATE_SPHERE_METADATA)
    params = execution.params(params)
    cargs = surface_create_sphere_cargs(params, execution)
    ret = surface_create_sphere_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_create_sphere(
    num_vertices: int,
    sphere_out: str,
    runner: Runner | None = None,
) -> SurfaceCreateSphereOutputs:
    """
    surface-create-sphere
    
    Generate a sphere with consistent vertex areas.
    
    Generates a sphere by regularly dividing the triangles of an icosahedron, to
    come as close to the desired number of vertices as possible, and modifying
    it to have very similar vertex areas for all vertices. To generate a pair of
    vertex-matched left and right spheres, use this command, then
    -surface-flip-lr to generate the other sphere, then -set-structure on each.
    For example:
    
    $ wb_command -surface-create-sphere 6000 Sphere.6k.R.surf.gii
    $ wb_command -surface-flip-lr Sphere.6k.R.surf.gii Sphere.6k.L.surf.gii
    $ wb_command -set-structure Sphere.6k.R.surf.gii CORTEX_RIGHT
    $ wb_command -set-structure Sphere.6k.L.surf.gii CORTEX_LEFT.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        num_vertices: desired number of vertices.
        sphere_out: the output sphere.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceCreateSphereOutputs`).
    """
    params = surface_create_sphere_params(
        num_vertices=num_vertices,
        sphere_out=sphere_out,
    )
    return surface_create_sphere_execute(params, runner)


__all__ = [
    "SURFACE_CREATE_SPHERE_METADATA",
    "SurfaceCreateSphereOutputs",
    "surface_create_sphere",
    "surface_create_sphere_execute",
    "surface_create_sphere_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

METRIC_FILL_HOLES_METADATA = Metadata(
    id="ac7f75738ed2f6a51844159ab8a7e0af250545a8.boutiques",
    name="metric-fill-holes",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


MetricFillHolesParameters = typing.TypedDict('MetricFillHolesParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/metric-fill-holes"]],
    "surface": InputPathType,
    "metric_in": InputPathType,
    "metric_out": str,
    "opt_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})
MetricFillHolesParametersTagged = typing.TypedDict('MetricFillHolesParametersTagged', {
    "@type": typing.Literal["workbench/metric-fill-holes"],
    "surface": InputPathType,
    "metric_in": InputPathType,
    "metric_out": str,
    "opt_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})


class MetricFillHolesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `MetricFillHolesParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output ROI metric"""


def metric_fill_holes_params(
    surface: InputPathType,
    metric_in: InputPathType,
    metric_out: str,
    opt_corrected_areas_area_metric: InputPathType | None = None,
) -> MetricFillHolesParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the surface to use for neighbor information.
        metric_in: the input ROI metric.
        metric_out: the output ROI metric.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/metric-fill-holes",
        "surface": surface,
        "metric_in": metric_in,
        "metric_out": metric_out,
    }
    if opt_corrected_areas_area_metric is not None:
        params["opt_corrected_areas_area_metric"] = opt_corrected_areas_area_metric
    return params


def metric_fill_holes_cargs(
    params: MetricFillHolesParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-fill-holes")
    cargs.append(execution.input_file(params.get("surface", None)))
    cargs.append(execution.input_file(params.get("metric_in", None)))
    cargs.append(params.get("metric_out", None))
    if params.get("opt_corrected_areas_area_metric", None) is not None:
        cargs.extend([
            "-corrected-areas",
            execution.input_file(params.get("opt_corrected_areas_area_metric", None))
        ])
    return cargs


def metric_fill_holes_outputs(
    params: MetricFillHolesParameters,
    execution: Execution,
) -> MetricFillHolesOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = MetricFillHolesOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(params.get("metric_out", None)),
    )
    return ret


def metric_fill_holes_execute(
    params: MetricFillHolesParameters,
    runner: Runner | None = None,
) -> MetricFillHolesOutputs:
    """
    metric-fill-holes
    
    Fill holes in an roi metric.
    
    Finds all connected areas that are not included in the ROI, and writes ones
    into all but the largest one, in terms of surface area.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricFillHolesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_FILL_HOLES_METADATA)
    params = execution.params(params)
    cargs = metric_fill_holes_cargs(params, execution)
    ret = metric_fill_holes_outputs(params, execution)
    execution.run(cargs)
    return ret


def metric_fill_holes(
    surface: InputPathType,
    metric_in: InputPathType,
    metric_out: str,
    opt_corrected_areas_area_metric: InputPathType | None = None,
    runner: Runner | None = None,
) -> MetricFillHolesOutputs:
    """
    metric-fill-holes
    
    Fill holes in an roi metric.
    
    Finds all connected areas that are not included in the ROI, and writes ones
    into all but the largest one, in terms of surface area.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface: the surface to use for neighbor information.
        metric_in: the input ROI metric.
        metric_out: the output ROI metric.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricFillHolesOutputs`).
    """
    params = metric_fill_holes_params(
        surface=surface,
        metric_in=metric_in,
        metric_out=metric_out,
        opt_corrected_areas_area_metric=opt_corrected_areas_area_metric,
    )
    return metric_fill_holes_execute(params, runner)


__all__ = [
    "METRIC_FILL_HOLES_METADATA",
    "MetricFillHolesOutputs",
    "metric_fill_holes",
    "metric_fill_holes_execute",
    "metric_fill_holes_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_EXPORT_DENSE_MAPPING_METADATA = Metadata(
    id="afadf58bea912ea0926f8e689df519c578fbdafa.boutiques",
    name="cifti-export-dense-mapping",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiExportDenseMappingVolumeAllParameters = typing.TypedDict('CiftiExportDenseMappingVolumeAllParameters', {
    "@type": typing.NotRequired[typing.Literal["volume_all"]],
    "text_out": str,
    "opt_no_cifti_index": bool,
    "opt_structure": bool,
})
CiftiExportDenseMappingVolumeAllParametersTagged = typing.TypedDict('CiftiExportDenseMappingVolumeAllParametersTagged', {
    "@type": typing.Literal["volume_all"],
    "text_out": str,
    "opt_no_cifti_index": bool,
    "opt_structure": bool,
})


CiftiExportDenseMappingSurfaceParameters = typing.TypedDict('CiftiExportDenseMappingSurfaceParameters', {
    "@type": typing.NotRequired[typing.Literal["surface"]],
    "structure": str,
    "text_out": str,
    "opt_no_cifti_index": bool,
})
CiftiExportDenseMappingSurfaceParametersTagged = typing.TypedDict('CiftiExportDenseMappingSurfaceParametersTagged', {
    "@type": typing.Literal["surface"],
    "structure": str,
    "text_out": str,
    "opt_no_cifti_index": bool,
})


CiftiExportDenseMappingVolumeParameters = typing.TypedDict('CiftiExportDenseMappingVolumeParameters', {
    "@type": typing.NotRequired[typing.Literal["volume"]],
    "structure": str,
    "text_out": str,
    "opt_no_cifti_index": bool,
})
CiftiExportDenseMappingVolumeParametersTagged = typing.TypedDict('CiftiExportDenseMappingVolumeParametersTagged', {
    "@type": typing.Literal["volume"],
    "structure": str,
    "text_out": str,
    "opt_no_cifti_index": bool,
})


CiftiExportDenseMappingParameters = typing.TypedDict('CiftiExportDenseMappingParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-export-dense-mapping"]],
    "cifti": InputPathType,
    "direction": str,
    "volume_all": typing.NotRequired[CiftiExportDenseMappingVolumeAllParameters | None],
    "surface": typing.NotRequired[list[CiftiExportDenseMappingSurfaceParameters] | None],
    "volume": typing.NotRequired[list[CiftiExportDenseMappingVolumeParameters] | None],
})
CiftiExportDenseMappingParametersTagged = typing.TypedDict('CiftiExportDenseMappingParametersTagged', {
    "@type": typing.Literal["workbench/cifti-export-dense-mapping"],
    "cifti": InputPathType,
    "direction": str,
    "volume_all": typing.NotRequired[CiftiExportDenseMappingVolumeAllParameters | None],
    "surface": typing.NotRequired[list[CiftiExportDenseMappingSurfaceParameters] | None],
    "volume": typing.NotRequired[list[CiftiExportDenseMappingVolumeParameters] | None],
})


def cifti_export_dense_mapping_volume_all_params(
    text_out: str,
    opt_no_cifti_index: bool = False,
    opt_structure: bool = False,
) -> CiftiExportDenseMappingVolumeAllParametersTagged:
    """
    Build parameters.
    
    Args:
        text_out: output - the output text file.
        opt_no_cifti_index: don't write the cifti index in the output file.
        opt_structure: write the structure each voxel belongs to in the output\
            file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "volume_all",
        "text_out": text_out,
        "opt_no_cifti_index": opt_no_cifti_index,
        "opt_structure": opt_structure,
    }
    return params


def cifti_export_dense_mapping_volume_all_cargs(
    params: CiftiExportDenseMappingVolumeAllParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-volume-all")
    cargs.append(params.get("text_out", None))
    if params.get("opt_no_cifti_index", False):
        cargs.append("-no-cifti-index")
    if params.get("opt_structure", False):
        cargs.append("-structure")
    return cargs


def cifti_export_dense_mapping_surface_params(
    structure: str,
    text_out: str,
    opt_no_cifti_index: bool = False,
) -> CiftiExportDenseMappingSurfaceParametersTagged:
    """
    Build parameters.
    
    Args:
        structure: the structure to output.
        text_out: output - the output text file.
        opt_no_cifti_index: don't write the cifti index in the output file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "surface",
        "structure": structure,
        "text_out": text_out,
        "opt_no_cifti_index": opt_no_cifti_index,
    }
    return params


def cifti_export_dense_mapping_surface_cargs(
    params: CiftiExportDenseMappingSurfaceParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-surface")
    cargs.append(params.get("structure", None))
    cargs.append(params.get("text_out", None))
    if params.get("opt_no_cifti_index", False):
        cargs.append("-no-cifti-index")
    return cargs


def cifti_export_dense_mapping_volume_params(
    structure: str,
    text_out: str,
    opt_no_cifti_index: bool = False,
) -> CiftiExportDenseMappingVolumeParametersTagged:
    """
    Build parameters.
    
    Args:
        structure: the structure to output.
        text_out: output - the output text file.
        opt_no_cifti_index: don't write the cifti index in the output file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "volume",
        "structure": structure,
        "text_out": text_out,
        "opt_no_cifti_index": opt_no_cifti_index,
    }
    return params


def cifti_export_dense_mapping_volume_cargs(
    params: CiftiExportDenseMappingVolumeParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-volume")
    cargs.append(params.get("structure", None))
    cargs.append(params.get("text_out", None))
    if params.get("opt_no_cifti_index", False):
        cargs.append("-no-cifti-index")
    return cargs


class CiftiExportDenseMappingOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiExportDenseMappingParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def cifti_export_dense_mapping_params(
    cifti: InputPathType,
    direction: str,
    volume_all: CiftiExportDenseMappingVolumeAllParameters | None = None,
    surface: list[CiftiExportDenseMappingSurfaceParameters] | None = None,
    volume: list[CiftiExportDenseMappingVolumeParameters] | None = None,
) -> CiftiExportDenseMappingParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti: the cifti file.
        direction: which direction to export the mapping from, ROW or COLUMN.
        volume_all: export the the mapping of all voxels.
        surface: export the the mapping of one surface structure.
        volume: export the the mapping of one volume structure.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-export-dense-mapping",
        "cifti": cifti,
        "direction": direction,
    }
    if volume_all is not None:
        params["volume_all"] = volume_all
    if surface is not None:
        params["surface"] = surface
    if volume is not None:
        params["volume"] = volume
    return params


def cifti_export_dense_mapping_cargs(
    params: CiftiExportDenseMappingParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-export-dense-mapping")
    cargs.append(execution.input_file(params.get("cifti", None)))
    cargs.append(params.get("direction", None))
    if params.get("volume_all", None) is not None:
        cargs.extend(cifti_export_dense_mapping_volume_all_cargs(params.get("volume_all", None), execution))
    if params.get("surface", None) is not None:
        cargs.extend([a for c in [cifti_export_dense_mapping_surface_cargs(s, execution) for s in params.get("surface", None)] for a in c])
    if params.get("volume", None) is not None:
        cargs.extend([a for c in [cifti_export_dense_mapping_volume_cargs(s, execution) for s in params.get("volume", None)] for a in c])
    return cargs


def cifti_export_dense_mapping_outputs(
    params: CiftiExportDenseMappingParameters,
    execution: Execution,
) -> CiftiExportDenseMappingOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiExportDenseMappingOutputs(
        root=execution.output_file("."),
    )
    return ret


def cifti_export_dense_mapping_execute(
    params: CiftiExportDenseMappingParameters,
    runner: Runner | None = None,
) -> CiftiExportDenseMappingOutputs:
    """
    cifti-export-dense-mapping
    
    Write index to element mapping as text.
    
    This command produces text files that describe the mapping from cifti
    indices to surface vertices or voxels. All indices are zero-based. The
    default format for -surface is lines of the form:
    
    <cifti-index> <vertex>
    
    The default format for -volume and -volume-all is lines of the form:
    
    <cifti-index> <i> <j> <k>
    
    For each <structure> argument, use one of the following strings:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiExportDenseMappingOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_EXPORT_DENSE_MAPPING_METADATA)
    params = execution.params(params)
    cargs = cifti_export_dense_mapping_cargs(params, execution)
    ret = cifti_export_dense_mapping_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_export_dense_mapping(
    cifti: InputPathType,
    direction: str,
    volume_all: CiftiExportDenseMappingVolumeAllParameters | None = None,
    surface: list[CiftiExportDenseMappingSurfaceParameters] | None = None,
    volume: list[CiftiExportDenseMappingVolumeParameters] | None = None,
    runner: Runner | None = None,
) -> CiftiExportDenseMappingOutputs:
    """
    cifti-export-dense-mapping
    
    Write index to element mapping as text.
    
    This command produces text files that describe the mapping from cifti
    indices to surface vertices or voxels. All indices are zero-based. The
    default format for -surface is lines of the form:
    
    <cifti-index> <vertex>
    
    The default format for -volume and -volume-all is lines of the form:
    
    <cifti-index> <i> <j> <k>
    
    For each <structure> argument, use one of the following strings:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti: the cifti file.
        direction: which direction to export the mapping from, ROW or COLUMN.
        volume_all: export the the mapping of all voxels.
        surface: export the the mapping of one surface structure.
        volume: export the the mapping of one volume structure.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiExportDenseMappingOutputs`).
    """
    params = cifti_export_dense_mapping_params(
        cifti=cifti,
        direction=direction,
        volume_all=volume_all,
        surface=surface,
        volume=volume,
    )
    return cifti_export_dense_mapping_execute(params, runner)


__all__ = [
    "CIFTI_EXPORT_DENSE_MAPPING_METADATA",
    "CiftiExportDenseMappingOutputs",
    "cifti_export_dense_mapping",
    "cifti_export_dense_mapping_execute",
    "cifti_export_dense_mapping_params",
    "cifti_export_dense_mapping_surface_params",
    "cifti_export_dense_mapping_volume_all_params",
    "cifti_export_dense_mapping_volume_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_GEODESIC_DISTANCE_METADATA = Metadata(
    id="b63b60aad75cad0af2e8476b6cd26a1b9f7a2e63.boutiques",
    name="surface-geodesic-distance",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceGeodesicDistanceParameters = typing.TypedDict('SurfaceGeodesicDistanceParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-geodesic-distance"]],
    "surface": InputPathType,
    "vertex": int,
    "metric_out": str,
    "opt_naive": bool,
    "opt_limit_limit_mm": typing.NotRequired[float | None],
    "opt_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})
SurfaceGeodesicDistanceParametersTagged = typing.TypedDict('SurfaceGeodesicDistanceParametersTagged', {
    "@type": typing.Literal["workbench/surface-geodesic-distance"],
    "surface": InputPathType,
    "vertex": int,
    "metric_out": str,
    "opt_naive": bool,
    "opt_limit_limit_mm": typing.NotRequired[float | None],
    "opt_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})


class SurfaceGeodesicDistanceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceGeodesicDistanceParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric"""


def surface_geodesic_distance_params(
    surface: InputPathType,
    vertex: int,
    metric_out: str,
    opt_naive: bool = False,
    opt_limit_limit_mm: float | None = None,
    opt_corrected_areas_area_metric: InputPathType | None = None,
) -> SurfaceGeodesicDistanceParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the surface to compute on.
        vertex: the vertex to compute geodesic distance from.
        metric_out: the output metric.
        opt_naive: use only neighbors, don't crawl triangles (not recommended).
        opt_limit_limit_mm: stop at a certain distance: distance in mm to stop\
            at.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-geodesic-distance",
        "surface": surface,
        "vertex": vertex,
        "metric_out": metric_out,
        "opt_naive": opt_naive,
    }
    if opt_limit_limit_mm is not None:
        params["opt_limit_limit_mm"] = opt_limit_limit_mm
    if opt_corrected_areas_area_metric is not None:
        params["opt_corrected_areas_area_metric"] = opt_corrected_areas_area_metric
    return params


def surface_geodesic_distance_cargs(
    params: SurfaceGeodesicDistanceParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-geodesic-distance")
    cargs.append(execution.input_file(params.get("surface", None)))
    cargs.append(str(params.get("vertex", None)))
    cargs.append(params.get("metric_out", None))
    if params.get("opt_naive", False):
        cargs.append("-naive")
    if params.get("opt_limit_limit_mm", None) is not None:
        cargs.extend([
            "-limit",
            str(params.get("opt_limit_limit_mm", None))
        ])
    if params.get("opt_corrected_areas_area_metric", None) is not None:
        cargs.extend([
            "-corrected-areas",
            execution.input_file(params.get("opt_corrected_areas_area_metric", None))
        ])
    return cargs


def surface_geodesic_distance_outputs(
    params: SurfaceGeodesicDistanceParameters,
    execution: Execution,
) -> SurfaceGeodesicDistanceOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceGeodesicDistanceOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(params.get("metric_out", None)),
    )
    return ret


def surface_geodesic_distance_execute(
    params: SurfaceGeodesicDistanceParameters,
    runner: Runner | None = None,
) -> SurfaceGeodesicDistanceOutputs:
    """
    surface-geodesic-distance
    
    Compute geodesic distance from one vertex to the entire surface.
    
    Unless -limit is specified, computes the geodesic distance from the
    specified vertex to all others. The result is output as a single column
    metric file, with a value of -1 for vertices that the distance was not
    computed for.
    
    The -corrected-areas option should be used when the input is a group average
    surface - group average surfaces have significantly less surface area than
    individual surfaces do, and therefore distances measured on them would be
    smaller than measuring them on individual surfaces. In this case, the input
    to this option should be a group average of the output of
    -surface-vertex-areas for each subject.
    
    If -naive is not specified, the algorithm uses not just immediate neighbors,
    but also neighbors derived from crawling across pairs of triangles that
    share an edge.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceGeodesicDistanceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_GEODESIC_DISTANCE_METADATA)
    params = execution.params(params)
    cargs = surface_geodesic_distance_cargs(params, execution)
    ret = surface_geodesic_distance_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_geodesic_distance(
    surface: InputPathType,
    vertex: int,
    metric_out: str,
    opt_naive: bool = False,
    opt_limit_limit_mm: float | None = None,
    opt_corrected_areas_area_metric: InputPathType | None = None,
    runner: Runner | None = None,
) -> SurfaceGeodesicDistanceOutputs:
    """
    surface-geodesic-distance
    
    Compute geodesic distance from one vertex to the entire surface.
    
    Unless -limit is specified, computes the geodesic distance from the
    specified vertex to all others. The result is output as a single column
    metric file, with a value of -1 for vertices that the distance was not
    computed for.
    
    The -corrected-areas option should be used when the input is a group average
    surface - group average surfaces have significantly less surface area than
    individual surfaces do, and therefore distances measured on them would be
    smaller than measuring them on individual surfaces. In this case, the input
    to this option should be a group average of the output of
    -surface-vertex-areas for each subject.
    
    If -naive is not specified, the algorithm uses not just immediate neighbors,
    but also neighbors derived from crawling across pairs of triangles that
    share an edge.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface: the surface to compute on.
        vertex: the vertex to compute geodesic distance from.
        metric_out: the output metric.
        opt_naive: use only neighbors, don't crawl triangles (not recommended).
        opt_limit_limit_mm: stop at a certain distance: distance in mm to stop\
            at.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceGeodesicDistanceOutputs`).
    """
    params = surface_geodesic_distance_params(
        surface=surface,
        vertex=vertex,
        metric_out=metric_out,
        opt_naive=opt_naive,
        opt_limit_limit_mm=opt_limit_limit_mm,
        opt_corrected_areas_area_metric=opt_corrected_areas_area_metric,
    )
    return surface_geodesic_distance_execute(params, runner)


__all__ = [
    "SURFACE_GEODESIC_DISTANCE_METADATA",
    "SurfaceGeodesicDistanceOutputs",
    "surface_geodesic_distance",
    "surface_geodesic_distance_execute",
    "surface_geodesic_distance_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_FLIP_NORMALS_METADATA = Metadata(
    id="8c4d88c8e5e251d057b6e23e7ae572f3f1462cc3.boutiques",
    name="surface-flip-normals",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceFlipNormalsParameters = typing.TypedDict('SurfaceFlipNormalsParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-flip-normals"]],
    "surface": InputPathType,
    "surface_out": str,
})
SurfaceFlipNormalsParametersTagged = typing.TypedDict('SurfaceFlipNormalsParametersTagged', {
    "@type": typing.Literal["workbench/surface-flip-normals"],
    "surface": InputPathType,
    "surface_out": str,
})


class SurfaceFlipNormalsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceFlipNormalsParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    surface_out: OutputPathType
    """the output surface"""


def surface_flip_normals_params(
    surface: InputPathType,
    surface_out: str,
) -> SurfaceFlipNormalsParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the surface to flip the normals of.
        surface_out: the output surface.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-flip-normals",
        "surface": surface,
        "surface_out": surface_out,
    }
    return params


def surface_flip_normals_cargs(
    params: SurfaceFlipNormalsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-flip-normals")
    cargs.append(execution.input_file(params.get("surface", None)))
    cargs.append(params.get("surface_out", None))
    return cargs


def surface_flip_normals_outputs(
    params: SurfaceFlipNormalsParameters,
    execution: Execution,
) -> SurfaceFlipNormalsOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceFlipNormalsOutputs(
        root=execution.output_file("."),
        surface_out=execution.output_file(params.get("surface_out", None)),
    )
    return ret


def surface_flip_normals_execute(
    params: SurfaceFlipNormalsParameters,
    runner: Runner | None = None,
) -> SurfaceFlipNormalsOutputs:
    """
    surface-flip-normals
    
    Flip all tiles on a surface.
    
    Flips all triangles on a surface, resulting in surface normals being flipped
    the other direction (inward vs outward). If you transform a surface with an
    affine that has negative determinant, or a warpfield that similarly flips
    the surface, you may end up with a surface that has normals pointing
    inwards, which may have display problems. Using this command will solve that
    problem.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceFlipNormalsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_FLIP_NORMALS_METADATA)
    params = execution.params(params)
    cargs = surface_flip_normals_cargs(params, execution)
    ret = surface_flip_normals_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_flip_normals(
    surface: InputPathType,
    surface_out: str,
    runner: Runner | None = None,
) -> SurfaceFlipNormalsOutputs:
    """
    surface-flip-normals
    
    Flip all tiles on a surface.
    
    Flips all triangles on a surface, resulting in surface normals being flipped
    the other direction (inward vs outward). If you transform a surface with an
    affine that has negative determinant, or a warpfield that similarly flips
    the surface, you may end up with a surface that has normals pointing
    inwards, which may have display problems. Using this command will solve that
    problem.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface: the surface to flip the normals of.
        surface_out: the output surface.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceFlipNormalsOutputs`).
    """
    params = surface_flip_normals_params(
        surface=surface,
        surface_out=surface_out,
    )
    return surface_flip_normals_execute(params, runner)


__all__ = [
    "SURFACE_FLIP_NORMALS_METADATA",
    "SurfaceFlipNormalsOutputs",
    "surface_flip_normals",
    "surface_flip_normals_execute",
    "surface_flip_normals_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CONVERT_FIBER_ORIENTATIONS_METADATA = Metadata(
    id="848dea6b577ee4b94a5e883dc7976a17d71a95af.boutiques",
    name="convert-fiber-orientations",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


ConvertFiberOrientationsFiberParameters = typing.TypedDict('ConvertFiberOrientationsFiberParameters', {
    "@type": typing.NotRequired[typing.Literal["fiber"]],
    "mean_f": InputPathType,
    "stdev_f": InputPathType,
    "theta": InputPathType,
    "phi": InputPathType,
    "psi": InputPathType,
    "ka": InputPathType,
    "kb": InputPathType,
})
ConvertFiberOrientationsFiberParametersTagged = typing.TypedDict('ConvertFiberOrientationsFiberParametersTagged', {
    "@type": typing.Literal["fiber"],
    "mean_f": InputPathType,
    "stdev_f": InputPathType,
    "theta": InputPathType,
    "phi": InputPathType,
    "psi": InputPathType,
    "ka": InputPathType,
    "kb": InputPathType,
})


ConvertFiberOrientationsParameters = typing.TypedDict('ConvertFiberOrientationsParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/convert-fiber-orientations"]],
    "label_volume": InputPathType,
    "fiber_out": str,
    "fiber": typing.NotRequired[list[ConvertFiberOrientationsFiberParameters] | None],
})
ConvertFiberOrientationsParametersTagged = typing.TypedDict('ConvertFiberOrientationsParametersTagged', {
    "@type": typing.Literal["workbench/convert-fiber-orientations"],
    "label_volume": InputPathType,
    "fiber_out": str,
    "fiber": typing.NotRequired[list[ConvertFiberOrientationsFiberParameters] | None],
})


def convert_fiber_orientations_fiber_params(
    mean_f: InputPathType,
    stdev_f: InputPathType,
    theta: InputPathType,
    phi: InputPathType,
    psi: InputPathType,
    ka: InputPathType,
    kb: InputPathType,
) -> ConvertFiberOrientationsFiberParametersTagged:
    """
    Build parameters.
    
    Args:
        mean_f: mean fiber strength.
        stdev_f: standard deviation of fiber strength.
        theta: theta angle.
        phi: phi angle.
        psi: psi angle.
        ka: ka bingham parameter.
        kb: kb bingham parameter.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "fiber",
        "mean_f": mean_f,
        "stdev_f": stdev_f,
        "theta": theta,
        "phi": phi,
        "psi": psi,
        "ka": ka,
        "kb": kb,
    }
    return params


def convert_fiber_orientations_fiber_cargs(
    params: ConvertFiberOrientationsFiberParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-fiber")
    cargs.append(execution.input_file(params.get("mean_f", None)))
    cargs.append(execution.input_file(params.get("stdev_f", None)))
    cargs.append(execution.input_file(params.get("theta", None)))
    cargs.append(execution.input_file(params.get("phi", None)))
    cargs.append(execution.input_file(params.get("psi", None)))
    cargs.append(execution.input_file(params.get("ka", None)))
    cargs.append(execution.input_file(params.get("kb", None)))
    return cargs


class ConvertFiberOrientationsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ConvertFiberOrientationsParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    fiber_out: OutputPathType
    """the output fiber orientation file"""


def convert_fiber_orientations_params(
    label_volume: InputPathType,
    fiber_out: str,
    fiber: list[ConvertFiberOrientationsFiberParameters] | None = None,
) -> ConvertFiberOrientationsParametersTagged:
    """
    Build parameters.
    
    Args:
        label_volume: volume of cifti structure labels.
        fiber_out: the output fiber orientation file.
        fiber: specify the parameter volumes for a fiber.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/convert-fiber-orientations",
        "label_volume": label_volume,
        "fiber_out": fiber_out,
    }
    if fiber is not None:
        params["fiber"] = fiber
    return params


def convert_fiber_orientations_cargs(
    params: ConvertFiberOrientationsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-convert-fiber-orientations")
    cargs.append(execution.input_file(params.get("label_volume", None)))
    cargs.append(params.get("fiber_out", None))
    if params.get("fiber", None) is not None:
        cargs.extend([a for c in [convert_fiber_orientations_fiber_cargs(s, execution) for s in params.get("fiber", None)] for a in c])
    return cargs


def convert_fiber_orientations_outputs(
    params: ConvertFiberOrientationsParameters,
    execution: Execution,
) -> ConvertFiberOrientationsOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = ConvertFiberOrientationsOutputs(
        root=execution.output_file("."),
        fiber_out=execution.output_file(params.get("fiber_out", None)),
    )
    return ret


def convert_fiber_orientations_execute(
    params: ConvertFiberOrientationsParameters,
    runner: Runner | None = None,
) -> ConvertFiberOrientationsOutputs:
    """
    convert-fiber-orientations
    
    Convert bingham parameter volumes to fiber orientation file.
    
    Takes precomputed bingham parameters from volume files and converts them to
    the format workbench uses for display. The <label-volume> argument must be a
    label volume, where the labels use these strings:
    
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConvertFiberOrientationsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CONVERT_FIBER_ORIENTATIONS_METADATA)
    params = execution.params(params)
    cargs = convert_fiber_orientations_cargs(params, execution)
    ret = convert_fiber_orientations_outputs(params, execution)
    execution.run(cargs)
    return ret


def convert_fiber_orientations(
    label_volume: InputPathType,
    fiber_out: str,
    fiber: list[ConvertFiberOrientationsFiberParameters] | None = None,
    runner: Runner | None = None,
) -> ConvertFiberOrientationsOutputs:
    """
    convert-fiber-orientations
    
    Convert bingham parameter volumes to fiber orientation file.
    
    Takes precomputed bingham parameters from volume files and converts them to
    the format workbench uses for display. The <label-volume> argument must be a
    label volume, where the labels use these strings:
    
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        label_volume: volume of cifti structure labels.
        fiber_out: the output fiber orientation file.
        fiber: specify the parameter volumes for a fiber.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConvertFiberOrientationsOutputs`).
    """
    params = convert_fiber_orientations_params(
        label_volume=label_volume,
        fiber_out=fiber_out,
        fiber=fiber,
    )
    return convert_fiber_orientations_execute(params, runner)


__all__ = [
    "CONVERT_FIBER_ORIENTATIONS_METADATA",
    "ConvertFiberOrientationsOutputs",
    "convert_fiber_orientations",
    "convert_fiber_orientations_execute",
    "convert_fiber_orientations_fiber_params",
    "convert_fiber_orientations_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_WEDGE_VOLUME_METADATA = Metadata(
    id="e5f6617fc469136137d2ad521599b19078079c17.boutiques",
    name="surface-wedge-volume",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceWedgeVolumeParameters = typing.TypedDict('SurfaceWedgeVolumeParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-wedge-volume"]],
    "inner_surface": InputPathType,
    "outer_surface": InputPathType,
    "metric": str,
})
SurfaceWedgeVolumeParametersTagged = typing.TypedDict('SurfaceWedgeVolumeParametersTagged', {
    "@type": typing.Literal["workbench/surface-wedge-volume"],
    "inner_surface": InputPathType,
    "outer_surface": InputPathType,
    "metric": str,
})


class SurfaceWedgeVolumeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceWedgeVolumeParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric: OutputPathType
    """the output metric"""


def surface_wedge_volume_params(
    inner_surface: InputPathType,
    outer_surface: InputPathType,
    metric: str,
) -> SurfaceWedgeVolumeParametersTagged:
    """
    Build parameters.
    
    Args:
        inner_surface: the inner surface.
        outer_surface: the outer surface.
        metric: the output metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-wedge-volume",
        "inner_surface": inner_surface,
        "outer_surface": outer_surface,
        "metric": metric,
    }
    return params


def surface_wedge_volume_cargs(
    params: SurfaceWedgeVolumeParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-wedge-volume")
    cargs.append(execution.input_file(params.get("inner_surface", None)))
    cargs.append(execution.input_file(params.get("outer_surface", None)))
    cargs.append(params.get("metric", None))
    return cargs


def surface_wedge_volume_outputs(
    params: SurfaceWedgeVolumeParameters,
    execution: Execution,
) -> SurfaceWedgeVolumeOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceWedgeVolumeOutputs(
        root=execution.output_file("."),
        metric=execution.output_file(params.get("metric", None)),
    )
    return ret


def surface_wedge_volume_execute(
    params: SurfaceWedgeVolumeParameters,
    runner: Runner | None = None,
) -> SurfaceWedgeVolumeOutputs:
    """
    surface-wedge-volume
    
    Measure per-vertex volume between surfaces.
    
    Compute the volume of each vertex's area from one surface to another. The
    surfaces must have vertex correspondence, and have consistent triangle
    orientation.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceWedgeVolumeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_WEDGE_VOLUME_METADATA)
    params = execution.params(params)
    cargs = surface_wedge_volume_cargs(params, execution)
    ret = surface_wedge_volume_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_wedge_volume(
    inner_surface: InputPathType,
    outer_surface: InputPathType,
    metric: str,
    runner: Runner | None = None,
) -> SurfaceWedgeVolumeOutputs:
    """
    surface-wedge-volume
    
    Measure per-vertex volume between surfaces.
    
    Compute the volume of each vertex's area from one surface to another. The
    surfaces must have vertex correspondence, and have consistent triangle
    orientation.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        inner_surface: the inner surface.
        outer_surface: the outer surface.
        metric: the output metric.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceWedgeVolumeOutputs`).
    """
    params = surface_wedge_volume_params(
        inner_surface=inner_surface,
        outer_surface=outer_surface,
        metric=metric,
    )
    return surface_wedge_volume_execute(params, runner)


__all__ = [
    "SURFACE_WEDGE_VOLUME_METADATA",
    "SurfaceWedgeVolumeOutputs",
    "surface_wedge_volume",
    "surface_wedge_volume_execute",
    "surface_wedge_volume_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_LABEL_IMPORT_METADATA = Metadata(
    id="ff57f7adfa683ce934248ecdc96b3c5c9f99b22e.boutiques",
    name="cifti-label-import",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiLabelImportParameters = typing.TypedDict('CiftiLabelImportParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-label-import"]],
    "input": InputPathType,
    "label_list_file": str,
    "output": str,
    "opt_discard_others": bool,
    "opt_unlabeled_value_value": typing.NotRequired[int | None],
    "opt_drop_unused_labels": bool,
})
CiftiLabelImportParametersTagged = typing.TypedDict('CiftiLabelImportParametersTagged', {
    "@type": typing.Literal["workbench/cifti-label-import"],
    "input": InputPathType,
    "label_list_file": str,
    "output": str,
    "opt_discard_others": bool,
    "opt_unlabeled_value_value": typing.NotRequired[int | None],
    "opt_drop_unused_labels": bool,
})


class CiftiLabelImportOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiLabelImportParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """the output cifti label file"""


def cifti_label_import_params(
    input_: InputPathType,
    label_list_file: str,
    output: str,
    opt_discard_others: bool = False,
    opt_unlabeled_value_value: int | None = None,
    opt_drop_unused_labels: bool = False,
) -> CiftiLabelImportParametersTagged:
    """
    Build parameters.
    
    Args:
        input_: the input cifti file.
        label_list_file: text file containing the values and names for labels.
        output: the output cifti label file.
        opt_discard_others: set any values not mentioned in the label list to\
            the ??? label.
        opt_unlabeled_value_value: set the value that will be interpreted as\
            unlabeled: the numeric value for unlabeled (default 0).
        opt_drop_unused_labels: remove any unused label values from the label\
            table.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-label-import",
        "input": input_,
        "label_list_file": label_list_file,
        "output": output,
        "opt_discard_others": opt_discard_others,
        "opt_drop_unused_labels": opt_drop_unused_labels,
    }
    if opt_unlabeled_value_value is not None:
        params["opt_unlabeled_value_value"] = opt_unlabeled_value_value
    return params


def cifti_label_import_cargs(
    params: CiftiLabelImportParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-label-import")
    cargs.append(execution.input_file(params.get("input", None)))
    cargs.append(params.get("label_list_file", None))
    cargs.append(params.get("output", None))
    if params.get("opt_discard_others", False):
        cargs.append("-discard-others")
    if params.get("opt_unlabeled_value_value", None) is not None:
        cargs.extend([
            "-unlabeled-value",
            str(params.get("opt_unlabeled_value_value", None))
        ])
    if params.get("opt_drop_unused_labels", False):
        cargs.append("-drop-unused-labels")
    return cargs


def cifti_label_import_outputs(
    params: CiftiLabelImportParameters,
    execution: Execution,
) -> CiftiLabelImportOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiLabelImportOutputs(
        root=execution.output_file("."),
        output=execution.output_file(params.get("output", None)),
    )
    return ret


def cifti_label_import_execute(
    params: CiftiLabelImportParameters,
    runner: Runner | None = None,
) -> CiftiLabelImportOutputs:
    """
    cifti-label-import
    
    Make a cifti label file from a cifti file.
    
    Creates a cifti label file from a cifti file with label-like values. You may
    specify the empty string (use "") for <label-list-file>, which will be
    treated as if it is an empty file. The label list file must have the
    following format (2 lines per label):
    
    <labelname>
    <key> <red> <green> <blue> <alpha>
    ...
    
    Label names are specified on a separate line from their value and color, in
    order to let label names contain spaces. Whitespace is trimmed from both
    ends of the label name, but is kept if it is in the middle of a label. Do
    not specify the "unlabeled" key in the file, it is assumed that 0 means not
    labeled unless -unlabeled-value is specified. The value of <key> specifies
    what value in the imported file should be used as this label (these same key
    values are also used in the output file). The values of <red>, <green>,
    <blue> and <alpha> must be integers from 0 to 255, and will specify the
    color the label is drawn as (alpha of 255 means fully opaque, which is
    probably what you want).
    
    By default, it will create new label names with names like LABEL_5 for any
    values encountered that are not mentioned in the list file, specify
    -discard-others to instead set these values to the "unlabeled" key.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiLabelImportOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_LABEL_IMPORT_METADATA)
    params = execution.params(params)
    cargs = cifti_label_import_cargs(params, execution)
    ret = cifti_label_import_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_label_import(
    input_: InputPathType,
    label_list_file: str,
    output: str,
    opt_discard_others: bool = False,
    opt_unlabeled_value_value: int | None = None,
    opt_drop_unused_labels: bool = False,
    runner: Runner | None = None,
) -> CiftiLabelImportOutputs:
    """
    cifti-label-import
    
    Make a cifti label file from a cifti file.
    
    Creates a cifti label file from a cifti file with label-like values. You may
    specify the empty string (use "") for <label-list-file>, which will be
    treated as if it is an empty file. The label list file must have the
    following format (2 lines per label):
    
    <labelname>
    <key> <red> <green> <blue> <alpha>
    ...
    
    Label names are specified on a separate line from their value and color, in
    order to let label names contain spaces. Whitespace is trimmed from both
    ends of the label name, but is kept if it is in the middle of a label. Do
    not specify the "unlabeled" key in the file, it is assumed that 0 means not
    labeled unless -unlabeled-value is specified. The value of <key> specifies
    what value in the imported file should be used as this label (these same key
    values are also used in the output file). The values of <red>, <green>,
    <blue> and <alpha> must be integers from 0 to 255, and will specify the
    color the label is drawn as (alpha of 255 means fully opaque, which is
    probably what you want).
    
    By default, it will create new label names with names like LABEL_5 for any
    values encountered that are not mentioned in the list file, specify
    -discard-others to instead set these values to the "unlabeled" key.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        input_: the input cifti file.
        label_list_file: text file containing the values and names for labels.
        output: the output cifti label file.
        opt_discard_others: set any values not mentioned in the label list to\
            the ??? label.
        opt_unlabeled_value_value: set the value that will be interpreted as\
            unlabeled: the numeric value for unlabeled (default 0).
        opt_drop_unused_labels: remove any unused label values from the label\
            table.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiLabelImportOutputs`).
    """
    params = cifti_label_import_params(
        input_=input_,
        label_list_file=label_list_file,
        output=output,
        opt_discard_others=opt_discard_others,
        opt_unlabeled_value_value=opt_unlabeled_value_value,
        opt_drop_unused_labels=opt_drop_unused_labels,
    )
    return cifti_label_import_execute(params, runner)


__all__ = [
    "CIFTI_LABEL_IMPORT_METADATA",
    "CiftiLabelImportOutputs",
    "cifti_label_import",
    "cifti_label_import_execute",
    "cifti_label_import_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

NIFTI_INFORMATION_METADATA = Metadata(
    id="a23892d08c899f32fc5adc3d462a0e9f07f36b16.boutiques",
    name="nifti-information",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


NiftiInformationPrintHeaderParameters = typing.TypedDict('NiftiInformationPrintHeaderParameters', {
    "@type": typing.NotRequired[typing.Literal["print_header"]],
    "opt_allow_truncated": bool,
})
NiftiInformationPrintHeaderParametersTagged = typing.TypedDict('NiftiInformationPrintHeaderParametersTagged', {
    "@type": typing.Literal["print_header"],
    "opt_allow_truncated": bool,
})


NiftiInformationPrintXmlParameters = typing.TypedDict('NiftiInformationPrintXmlParameters', {
    "@type": typing.NotRequired[typing.Literal["print_xml"]],
    "opt_version_version": typing.NotRequired[str | None],
})
NiftiInformationPrintXmlParametersTagged = typing.TypedDict('NiftiInformationPrintXmlParametersTagged', {
    "@type": typing.Literal["print_xml"],
    "opt_version_version": typing.NotRequired[str | None],
})


NiftiInformationParameters = typing.TypedDict('NiftiInformationParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/nifti-information"]],
    "nifti_file": str,
    "print_header": typing.NotRequired[NiftiInformationPrintHeaderParameters | None],
    "opt_print_matrix": bool,
    "print_xml": typing.NotRequired[NiftiInformationPrintXmlParameters | None],
})
NiftiInformationParametersTagged = typing.TypedDict('NiftiInformationParametersTagged', {
    "@type": typing.Literal["workbench/nifti-information"],
    "nifti_file": str,
    "print_header": typing.NotRequired[NiftiInformationPrintHeaderParameters | None],
    "opt_print_matrix": bool,
    "print_xml": typing.NotRequired[NiftiInformationPrintXmlParameters | None],
})


def nifti_information_print_header_params(
    opt_allow_truncated: bool = False,
) -> NiftiInformationPrintHeaderParametersTagged:
    """
    Build parameters.
    
    Args:
        opt_allow_truncated: print the header even if the data is truncated.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "print_header",
        "opt_allow_truncated": opt_allow_truncated,
    }
    return params


def nifti_information_print_header_cargs(
    params: NiftiInformationPrintHeaderParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-print-header")
    if params.get("opt_allow_truncated", False):
        cargs.append("-allow-truncated")
    return cargs


def nifti_information_print_xml_params(
    opt_version_version: str | None = None,
) -> NiftiInformationPrintXmlParametersTagged:
    """
    Build parameters.
    
    Args:
        opt_version_version: convert the XML to a specific CIFTI version\
            (default is the file's cifti version): the CIFTI version to use.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "print_xml",
    }
    if opt_version_version is not None:
        params["opt_version_version"] = opt_version_version
    return params


def nifti_information_print_xml_cargs(
    params: NiftiInformationPrintXmlParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-print-xml")
    if params.get("opt_version_version", None) is not None:
        cargs.extend([
            "-version",
            params.get("opt_version_version", None)
        ])
    return cargs


class NiftiInformationOutputs(typing.NamedTuple):
    """
    Output object returned when calling `NiftiInformationParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def nifti_information_params(
    nifti_file: str,
    print_header: NiftiInformationPrintHeaderParameters | None = None,
    opt_print_matrix: bool = False,
    print_xml: NiftiInformationPrintXmlParameters | None = None,
) -> NiftiInformationParametersTagged:
    """
    Build parameters.
    
    Args:
        nifti_file: the nifti/cifti file to examine.
        print_header: display the header contents.
        opt_print_matrix: output the values in the matrix (cifti only).
        print_xml: print the cifti XML (cifti only).
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/nifti-information",
        "nifti_file": nifti_file,
        "opt_print_matrix": opt_print_matrix,
    }
    if print_header is not None:
        params["print_header"] = print_header
    if print_xml is not None:
        params["print_xml"] = print_xml
    return params


def nifti_information_cargs(
    params: NiftiInformationParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-nifti-information")
    cargs.append(params.get("nifti_file", None))
    if params.get("print_header", None) is not None:
        cargs.extend(nifti_information_print_header_cargs(params.get("print_header", None), execution))
    if params.get("opt_print_matrix", False):
        cargs.append("-print-matrix")
    if params.get("print_xml", None) is not None:
        cargs.extend(nifti_information_print_xml_cargs(params.get("print_xml", None), execution))
    return cargs


def nifti_information_outputs(
    params: NiftiInformationParameters,
    execution: Execution,
) -> NiftiInformationOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = NiftiInformationOutputs(
        root=execution.output_file("."),
    )
    return ret


def nifti_information_execute(
    params: NiftiInformationParameters,
    runner: Runner | None = None,
) -> NiftiInformationOutputs:
    """
    nifti-information
    
    Display information about a nifti/cifti file.
    
    You must specify at least one -print-* option.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `NiftiInformationOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(NIFTI_INFORMATION_METADATA)
    params = execution.params(params)
    cargs = nifti_information_cargs(params, execution)
    ret = nifti_information_outputs(params, execution)
    execution.run(cargs)
    return ret


def nifti_information(
    nifti_file: str,
    print_header: NiftiInformationPrintHeaderParameters | None = None,
    opt_print_matrix: bool = False,
    print_xml: NiftiInformationPrintXmlParameters | None = None,
    runner: Runner | None = None,
) -> NiftiInformationOutputs:
    """
    nifti-information
    
    Display information about a nifti/cifti file.
    
    You must specify at least one -print-* option.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        nifti_file: the nifti/cifti file to examine.
        print_header: display the header contents.
        opt_print_matrix: output the values in the matrix (cifti only).
        print_xml: print the cifti XML (cifti only).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `NiftiInformationOutputs`).
    """
    params = nifti_information_params(
        nifti_file=nifti_file,
        print_header=print_header,
        opt_print_matrix=opt_print_matrix,
        print_xml=print_xml,
    )
    return nifti_information_execute(params, runner)


__all__ = [
    "NIFTI_INFORMATION_METADATA",
    "NiftiInformationOutputs",
    "nifti_information",
    "nifti_information_execute",
    "nifti_information_params",
    "nifti_information_print_header_params",
    "nifti_information_print_xml_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_SMOOTHING_METADATA = Metadata(
    id="0b87cc9cdd0f0460a8ebb1583ddeff5398d57bd4.boutiques",
    name="cifti-smoothing",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiSmoothingLeftSurfaceParameters = typing.TypedDict('CiftiSmoothingLeftSurfaceParameters', {
    "@type": typing.NotRequired[typing.Literal["left_surface"]],
    "surface": InputPathType,
    "opt_left_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})
CiftiSmoothingLeftSurfaceParametersTagged = typing.TypedDict('CiftiSmoothingLeftSurfaceParametersTagged', {
    "@type": typing.Literal["left_surface"],
    "surface": InputPathType,
    "opt_left_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})


CiftiSmoothingRightSurfaceParameters = typing.TypedDict('CiftiSmoothingRightSurfaceParameters', {
    "@type": typing.NotRequired[typing.Literal["right_surface"]],
    "surface": InputPathType,
    "opt_right_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})
CiftiSmoothingRightSurfaceParametersTagged = typing.TypedDict('CiftiSmoothingRightSurfaceParametersTagged', {
    "@type": typing.Literal["right_surface"],
    "surface": InputPathType,
    "opt_right_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})


CiftiSmoothingCerebellumSurfaceParameters = typing.TypedDict('CiftiSmoothingCerebellumSurfaceParameters', {
    "@type": typing.NotRequired[typing.Literal["cerebellum_surface"]],
    "surface": InputPathType,
    "opt_cerebellum_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})
CiftiSmoothingCerebellumSurfaceParametersTagged = typing.TypedDict('CiftiSmoothingCerebellumSurfaceParametersTagged', {
    "@type": typing.Literal["cerebellum_surface"],
    "surface": InputPathType,
    "opt_cerebellum_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})


CiftiSmoothingParameters = typing.TypedDict('CiftiSmoothingParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-smoothing"]],
    "cifti": InputPathType,
    "surface_kernel": float,
    "volume_kernel": float,
    "direction": str,
    "cifti_out": str,
    "opt_fwhm": bool,
    "left_surface": typing.NotRequired[CiftiSmoothingLeftSurfaceParameters | None],
    "right_surface": typing.NotRequired[CiftiSmoothingRightSurfaceParameters | None],
    "cerebellum_surface": typing.NotRequired[CiftiSmoothingCerebellumSurfaceParameters | None],
    "opt_cifti_roi_roi_cifti": typing.NotRequired[InputPathType | None],
    "opt_fix_zeros_volume": bool,
    "opt_fix_zeros_surface": bool,
    "opt_merged_volume": bool,
})
CiftiSmoothingParametersTagged = typing.TypedDict('CiftiSmoothingParametersTagged', {
    "@type": typing.Literal["workbench/cifti-smoothing"],
    "cifti": InputPathType,
    "surface_kernel": float,
    "volume_kernel": float,
    "direction": str,
    "cifti_out": str,
    "opt_fwhm": bool,
    "left_surface": typing.NotRequired[CiftiSmoothingLeftSurfaceParameters | None],
    "right_surface": typing.NotRequired[CiftiSmoothingRightSurfaceParameters | None],
    "cerebellum_surface": typing.NotRequired[CiftiSmoothingCerebellumSurfaceParameters | None],
    "opt_cifti_roi_roi_cifti": typing.NotRequired[InputPathType | None],
    "opt_fix_zeros_volume": bool,
    "opt_fix_zeros_surface": bool,
    "opt_merged_volume": bool,
})


def cifti_smoothing_left_surface_params(
    surface: InputPathType,
    opt_left_corrected_areas_area_metric: InputPathType | None = None,
) -> CiftiSmoothingLeftSurfaceParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the left surface file.
        opt_left_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the left surface: the corrected vertex areas, as a\
            metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "left_surface",
        "surface": surface,
    }
    if opt_left_corrected_areas_area_metric is not None:
        params["opt_left_corrected_areas_area_metric"] = opt_left_corrected_areas_area_metric
    return params


def cifti_smoothing_left_surface_cargs(
    params: CiftiSmoothingLeftSurfaceParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-left-surface")
    cargs.append(execution.input_file(params.get("surface", None)))
    if params.get("opt_left_corrected_areas_area_metric", None) is not None:
        cargs.extend([
            "-left-corrected-areas",
            execution.input_file(params.get("opt_left_corrected_areas_area_metric", None))
        ])
    return cargs


def cifti_smoothing_right_surface_params(
    surface: InputPathType,
    opt_right_corrected_areas_area_metric: InputPathType | None = None,
) -> CiftiSmoothingRightSurfaceParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the right surface file.
        opt_right_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the right surface: the corrected vertex areas, as a\
            metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "right_surface",
        "surface": surface,
    }
    if opt_right_corrected_areas_area_metric is not None:
        params["opt_right_corrected_areas_area_metric"] = opt_right_corrected_areas_area_metric
    return params


def cifti_smoothing_right_surface_cargs(
    params: CiftiSmoothingRightSurfaceParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-right-surface")
    cargs.append(execution.input_file(params.get("surface", None)))
    if params.get("opt_right_corrected_areas_area_metric", None) is not None:
        cargs.extend([
            "-right-corrected-areas",
            execution.input_file(params.get("opt_right_corrected_areas_area_metric", None))
        ])
    return cargs


def cifti_smoothing_cerebellum_surface_params(
    surface: InputPathType,
    opt_cerebellum_corrected_areas_area_metric: InputPathType | None = None,
) -> CiftiSmoothingCerebellumSurfaceParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the cerebellum surface file.
        opt_cerebellum_corrected_areas_area_metric: vertex areas to use instead\
            of computing them from the cerebellum surface: the corrected vertex\
            areas, as a metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "cerebellum_surface",
        "surface": surface,
    }
    if opt_cerebellum_corrected_areas_area_metric is not None:
        params["opt_cerebellum_corrected_areas_area_metric"] = opt_cerebellum_corrected_areas_area_metric
    return params


def cifti_smoothing_cerebellum_surface_cargs(
    params: CiftiSmoothingCerebellumSurfaceParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-cerebellum-surface")
    cargs.append(execution.input_file(params.get("surface", None)))
    if params.get("opt_cerebellum_corrected_areas_area_metric", None) is not None:
        cargs.extend([
            "-cerebellum-corrected-areas",
            execution.input_file(params.get("opt_cerebellum_corrected_areas_area_metric", None))
        ])
    return cargs


class CiftiSmoothingOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiSmoothingParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti"""


def cifti_smoothing_params(
    cifti: InputPathType,
    surface_kernel: float,
    volume_kernel: float,
    direction: str,
    cifti_out: str,
    opt_fwhm: bool = False,
    left_surface: CiftiSmoothingLeftSurfaceParameters | None = None,
    right_surface: CiftiSmoothingRightSurfaceParameters | None = None,
    cerebellum_surface: CiftiSmoothingCerebellumSurfaceParameters | None = None,
    opt_cifti_roi_roi_cifti: InputPathType | None = None,
    opt_fix_zeros_volume: bool = False,
    opt_fix_zeros_surface: bool = False,
    opt_merged_volume: bool = False,
) -> CiftiSmoothingParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti: the input cifti.
        surface_kernel: the size of the gaussian surface smoothing kernel in\
            mm, as sigma by default.
        volume_kernel: the size of the gaussian volume smoothing kernel in mm,\
            as sigma by default.
        direction: which dimension to smooth along, ROW or COLUMN.
        cifti_out: the output cifti.
        opt_fwhm: kernel sizes are FWHM, not sigma.
        left_surface: specify the left surface to use.
        right_surface: specify the right surface to use.
        cerebellum_surface: specify the cerebellum surface to use.
        opt_cifti_roi_roi_cifti: smooth only within regions of interest: the\
            regions to smooth within, as a cifti file.
        opt_fix_zeros_volume: treat values of zero in the volume as missing\
            data.
        opt_fix_zeros_surface: treat values of zero on the surface as missing\
            data.
        opt_merged_volume: smooth across subcortical structure boundaries.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-smoothing",
        "cifti": cifti,
        "surface_kernel": surface_kernel,
        "volume_kernel": volume_kernel,
        "direction": direction,
        "cifti_out": cifti_out,
        "opt_fwhm": opt_fwhm,
        "opt_fix_zeros_volume": opt_fix_zeros_volume,
        "opt_fix_zeros_surface": opt_fix_zeros_surface,
        "opt_merged_volume": opt_merged_volume,
    }
    if left_surface is not None:
        params["left_surface"] = left_surface
    if right_surface is not None:
        params["right_surface"] = right_surface
    if cerebellum_surface is not None:
        params["cerebellum_surface"] = cerebellum_surface
    if opt_cifti_roi_roi_cifti is not None:
        params["opt_cifti_roi_roi_cifti"] = opt_cifti_roi_roi_cifti
    return params


def cifti_smoothing_cargs(
    params: CiftiSmoothingParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-smoothing")
    cargs.append(execution.input_file(params.get("cifti", None)))
    cargs.append(str(params.get("surface_kernel", None)))
    cargs.append(str(params.get("volume_kernel", None)))
    cargs.append(params.get("direction", None))
    cargs.append(params.get("cifti_out", None))
    if params.get("opt_fwhm", False):
        cargs.append("-fwhm")
    if params.get("left_surface", None) is not None:
        cargs.extend(cifti_smoothing_left_surface_cargs(params.get("left_surface", None), execution))
    if params.get("right_surface", None) is not None:
        cargs.extend(cifti_smoothing_right_surface_cargs(params.get("right_surface", None), execution))
    if params.get("cerebellum_surface", None) is not None:
        cargs.extend(cifti_smoothing_cerebellum_surface_cargs(params.get("cerebellum_surface", None), execution))
    if params.get("opt_cifti_roi_roi_cifti", None) is not None:
        cargs.extend([
            "-cifti-roi",
            execution.input_file(params.get("opt_cifti_roi_roi_cifti", None))
        ])
    if params.get("opt_fix_zeros_volume", False):
        cargs.append("-fix-zeros-volume")
    if params.get("opt_fix_zeros_surface", False):
        cargs.append("-fix-zeros-surface")
    if params.get("opt_merged_volume", False):
        cargs.append("-merged-volume")
    return cargs


def cifti_smoothing_outputs(
    params: CiftiSmoothingParameters,
    execution: Execution,
) -> CiftiSmoothingOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiSmoothingOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


def cifti_smoothing_execute(
    params: CiftiSmoothingParameters,
    runner: Runner | None = None,
) -> CiftiSmoothingOutputs:
    """
    cifti-smoothing
    
    Smooth a cifti file.
    
    The input cifti file must have a brain models mapping on the chosen
    dimension, columns for .dtseries, and either for .dconn. By default, data in
    different structures is smoothed independently (i.e., "parcel constrained"
    smoothing), so volume structures that touch do not smooth across this
    boundary. Specify -merged-volume to ignore these boundaries. Surface
    smoothing uses the GEO_GAUSS_AREA smoothing method.
    
    The -*-corrected-areas options are intended for when it is unavoidable to
    smooth on group average surfaces, it is only an approximate correction for
    the reduction of structure in a group average surface. It is better to
    smooth the data on individuals before averaging, when feasible.
    
    The -fix-zeros-* options will treat values of zero as lack of data, and not
    use that value when generating the smoothed values, but will fill zeros with
    extrapolated values. The ROI should have a brain models mapping along
    columns, exactly matching the mapping of the chosen direction in the input
    file. Data outside the ROI is ignored.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiSmoothingOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_SMOOTHING_METADATA)
    params = execution.params(params)
    cargs = cifti_smoothing_cargs(params, execution)
    ret = cifti_smoothing_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_smoothing(
    cifti: InputPathType,
    surface_kernel: float,
    volume_kernel: float,
    direction: str,
    cifti_out: str,
    opt_fwhm: bool = False,
    left_surface: CiftiSmoothingLeftSurfaceParameters | None = None,
    right_surface: CiftiSmoothingRightSurfaceParameters | None = None,
    cerebellum_surface: CiftiSmoothingCerebellumSurfaceParameters | None = None,
    opt_cifti_roi_roi_cifti: InputPathType | None = None,
    opt_fix_zeros_volume: bool = False,
    opt_fix_zeros_surface: bool = False,
    opt_merged_volume: bool = False,
    runner: Runner | None = None,
) -> CiftiSmoothingOutputs:
    """
    cifti-smoothing
    
    Smooth a cifti file.
    
    The input cifti file must have a brain models mapping on the chosen
    dimension, columns for .dtseries, and either for .dconn. By default, data in
    different structures is smoothed independently (i.e., "parcel constrained"
    smoothing), so volume structures that touch do not smooth across this
    boundary. Specify -merged-volume to ignore these boundaries. Surface
    smoothing uses the GEO_GAUSS_AREA smoothing method.
    
    The -*-corrected-areas options are intended for when it is unavoidable to
    smooth on group average surfaces, it is only an approximate correction for
    the reduction of structure in a group average surface. It is better to
    smooth the data on individuals before averaging, when feasible.
    
    The -fix-zeros-* options will treat values of zero as lack of data, and not
    use that value when generating the smoothed values, but will fill zeros with
    extrapolated values. The ROI should have a brain models mapping along
    columns, exactly matching the mapping of the chosen direction in the input
    file. Data outside the ROI is ignored.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti: the input cifti.
        surface_kernel: the size of the gaussian surface smoothing kernel in\
            mm, as sigma by default.
        volume_kernel: the size of the gaussian volume smoothing kernel in mm,\
            as sigma by default.
        direction: which dimension to smooth along, ROW or COLUMN.
        cifti_out: the output cifti.
        opt_fwhm: kernel sizes are FWHM, not sigma.
        left_surface: specify the left surface to use.
        right_surface: specify the right surface to use.
        cerebellum_surface: specify the cerebellum surface to use.
        opt_cifti_roi_roi_cifti: smooth only within regions of interest: the\
            regions to smooth within, as a cifti file.
        opt_fix_zeros_volume: treat values of zero in the volume as missing\
            data.
        opt_fix_zeros_surface: treat values of zero on the surface as missing\
            data.
        opt_merged_volume: smooth across subcortical structure boundaries.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiSmoothingOutputs`).
    """
    params = cifti_smoothing_params(
        cifti=cifti,
        surface_kernel=surface_kernel,
        volume_kernel=volume_kernel,
        direction=direction,
        cifti_out=cifti_out,
        opt_fwhm=opt_fwhm,
        left_surface=left_surface,
        right_surface=right_surface,
        cerebellum_surface=cerebellum_surface,
        opt_cifti_roi_roi_cifti=opt_cifti_roi_roi_cifti,
        opt_fix_zeros_volume=opt_fix_zeros_volume,
        opt_fix_zeros_surface=opt_fix_zeros_surface,
        opt_merged_volume=opt_merged_volume,
    )
    return cifti_smoothing_execute(params, runner)


__all__ = [
    "CIFTI_SMOOTHING_METADATA",
    "CiftiSmoothingOutputs",
    "cifti_smoothing",
    "cifti_smoothing_cerebellum_surface_params",
    "cifti_smoothing_execute",
    "cifti_smoothing_left_surface_params",
    "cifti_smoothing_params",
    "cifti_smoothing_right_surface_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CONVERT_MATRIX4_TO_MATRIX2_METADATA = Metadata(
    id="0051a9c07cc746b7e076751b20f94d4b5687f120.boutiques",
    name="convert-matrix4-to-matrix2",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


ConvertMatrix4ToMatrix2IndividualFibersParameters = typing.TypedDict('ConvertMatrix4ToMatrix2IndividualFibersParameters', {
    "@type": typing.NotRequired[typing.Literal["individual_fibers"]],
    "fiber_1": str,
    "fiber_2": str,
    "fiber_3": str,
})
ConvertMatrix4ToMatrix2IndividualFibersParametersTagged = typing.TypedDict('ConvertMatrix4ToMatrix2IndividualFibersParametersTagged', {
    "@type": typing.Literal["individual_fibers"],
    "fiber_1": str,
    "fiber_2": str,
    "fiber_3": str,
})


ConvertMatrix4ToMatrix2Parameters = typing.TypedDict('ConvertMatrix4ToMatrix2Parameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/convert-matrix4-to-matrix2"]],
    "matrix4_wbsparse": str,
    "counts_out": str,
    "opt_distances_distance_out": typing.NotRequired[str | None],
    "individual_fibers": typing.NotRequired[ConvertMatrix4ToMatrix2IndividualFibersParameters | None],
})
ConvertMatrix4ToMatrix2ParametersTagged = typing.TypedDict('ConvertMatrix4ToMatrix2ParametersTagged', {
    "@type": typing.Literal["workbench/convert-matrix4-to-matrix2"],
    "matrix4_wbsparse": str,
    "counts_out": str,
    "opt_distances_distance_out": typing.NotRequired[str | None],
    "individual_fibers": typing.NotRequired[ConvertMatrix4ToMatrix2IndividualFibersParameters | None],
})


class ConvertMatrix4ToMatrix2IndividualFibersOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ConvertMatrix4ToMatrix2IndividualFibersParameters | None(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    fiber_1: OutputPathType
    """output file for first fiber"""
    fiber_2: OutputPathType
    """output file for second fiber"""
    fiber_3: OutputPathType
    """output file for third fiber"""


def convert_matrix4_to_matrix2_individual_fibers_params(
    fiber_1: str,
    fiber_2: str,
    fiber_3: str,
) -> ConvertMatrix4ToMatrix2IndividualFibersParametersTagged:
    """
    Build parameters.
    
    Args:
        fiber_1: output file for first fiber.
        fiber_2: output file for second fiber.
        fiber_3: output file for third fiber.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "individual_fibers",
        "fiber_1": fiber_1,
        "fiber_2": fiber_2,
        "fiber_3": fiber_3,
    }
    return params


def convert_matrix4_to_matrix2_individual_fibers_cargs(
    params: ConvertMatrix4ToMatrix2IndividualFibersParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-individual-fibers")
    cargs.append(params.get("fiber_1", None))
    cargs.append(params.get("fiber_2", None))
    cargs.append(params.get("fiber_3", None))
    return cargs


def convert_matrix4_to_matrix2_individual_fibers_outputs(
    params: ConvertMatrix4ToMatrix2IndividualFibersParameters,
    execution: Execution,
) -> ConvertMatrix4ToMatrix2IndividualFibersOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = ConvertMatrix4ToMatrix2IndividualFibersOutputs(
        root=execution.output_file("."),
        fiber_1=execution.output_file(params.get("fiber_1", None)),
        fiber_2=execution.output_file(params.get("fiber_2", None)),
        fiber_3=execution.output_file(params.get("fiber_3", None)),
    )
    return ret


class ConvertMatrix4ToMatrix2Outputs(typing.NamedTuple):
    """
    Output object returned when calling `ConvertMatrix4ToMatrix2Parameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    counts_out: OutputPathType
    """the total fiber counts, as a cifti file"""
    opt_distances_distance_out: OutputPathType | None
    """output average trajectory distance: the distances, as a cifti file"""
    individual_fibers: ConvertMatrix4ToMatrix2IndividualFibersOutputs | None
    """Outputs from `convert_matrix4_to_matrix2_individual_fibers_outputs`."""


def convert_matrix4_to_matrix2_params(
    matrix4_wbsparse: str,
    counts_out: str,
    opt_distances_distance_out: str | None = None,
    individual_fibers: ConvertMatrix4ToMatrix2IndividualFibersParameters | None = None,
) -> ConvertMatrix4ToMatrix2ParametersTagged:
    """
    Build parameters.
    
    Args:
        matrix4_wbsparse: a wbsparse matrix4 file.
        counts_out: the total fiber counts, as a cifti file.
        opt_distances_distance_out: output average trajectory distance: the\
            distances, as a cifti file.
        individual_fibers: output files for each fiber direction.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/convert-matrix4-to-matrix2",
        "matrix4_wbsparse": matrix4_wbsparse,
        "counts_out": counts_out,
    }
    if opt_distances_distance_out is not None:
        params["opt_distances_distance_out"] = opt_distances_distance_out
    if individual_fibers is not None:
        params["individual_fibers"] = individual_fibers
    return params


def convert_matrix4_to_matrix2_cargs(
    params: ConvertMatrix4ToMatrix2Parameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-convert-matrix4-to-matrix2")
    cargs.append(params.get("matrix4_wbsparse", None))
    cargs.append(params.get("counts_out", None))
    if params.get("opt_distances_distance_out", None) is not None:
        cargs.extend([
            "-distances",
            params.get("opt_distances_distance_out", None)
        ])
    if params.get("individual_fibers", None) is not None:
        cargs.extend(convert_matrix4_to_matrix2_individual_fibers_cargs(params.get("individual_fibers", None), execution))
    return cargs


def convert_matrix4_to_matrix2_outputs(
    params: ConvertMatrix4ToMatrix2Parameters,
    execution: Execution,
) -> ConvertMatrix4ToMatrix2Outputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = ConvertMatrix4ToMatrix2Outputs(
        root=execution.output_file("."),
        counts_out=execution.output_file(params.get("counts_out", None)),
        opt_distances_distance_out=execution.output_file(params.get("opt_distances_distance_out", None)) if (params.get("opt_distances_distance_out") is not None) else None,
        individual_fibers=convert_matrix4_to_matrix2_individual_fibers_outputs(params.get("individual_fibers"), execution) if params.get("individual_fibers") else None,
    )
    return ret


def convert_matrix4_to_matrix2_execute(
    params: ConvertMatrix4ToMatrix2Parameters,
    runner: Runner | None = None,
) -> ConvertMatrix4ToMatrix2Outputs:
    """
    convert-matrix4-to-matrix2
    
    Generates a matrix2 cifti from matrix4 wbsparse.
    
    This command makes a cifti file from the fiber counts in a matrix4 wbsparse
    file, and optionally a second cifti file from the distances. Note that while
    the total count is stored exactly, the per-fiber counts are stored as
    approximate fractions, so the output of -individual-fibers will contain
    nonintegers.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConvertMatrix4ToMatrix2Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CONVERT_MATRIX4_TO_MATRIX2_METADATA)
    params = execution.params(params)
    cargs = convert_matrix4_to_matrix2_cargs(params, execution)
    ret = convert_matrix4_to_matrix2_outputs(params, execution)
    execution.run(cargs)
    return ret


def convert_matrix4_to_matrix2(
    matrix4_wbsparse: str,
    counts_out: str,
    opt_distances_distance_out: str | None = None,
    individual_fibers: ConvertMatrix4ToMatrix2IndividualFibersParameters | None = None,
    runner: Runner | None = None,
) -> ConvertMatrix4ToMatrix2Outputs:
    """
    convert-matrix4-to-matrix2
    
    Generates a matrix2 cifti from matrix4 wbsparse.
    
    This command makes a cifti file from the fiber counts in a matrix4 wbsparse
    file, and optionally a second cifti file from the distances. Note that while
    the total count is stored exactly, the per-fiber counts are stored as
    approximate fractions, so the output of -individual-fibers will contain
    nonintegers.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        matrix4_wbsparse: a wbsparse matrix4 file.
        counts_out: the total fiber counts, as a cifti file.
        opt_distances_distance_out: output average trajectory distance: the\
            distances, as a cifti file.
        individual_fibers: output files for each fiber direction.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConvertMatrix4ToMatrix2Outputs`).
    """
    params = convert_matrix4_to_matrix2_params(
        matrix4_wbsparse=matrix4_wbsparse,
        counts_out=counts_out,
        opt_distances_distance_out=opt_distances_distance_out,
        individual_fibers=individual_fibers,
    )
    return convert_matrix4_to_matrix2_execute(params, runner)


__all__ = [
    "CONVERT_MATRIX4_TO_MATRIX2_METADATA",
    "ConvertMatrix4ToMatrix2IndividualFibersOutputs",
    "ConvertMatrix4ToMatrix2Outputs",
    "convert_matrix4_to_matrix2",
    "convert_matrix4_to_matrix2_execute",
    "convert_matrix4_to_matrix2_individual_fibers_params",
    "convert_matrix4_to_matrix2_params",
]
